@@ -1,6 +1,6 @@
 #!/bin/bash
 
-set -eu
+set -ue
 
 #for target in alpine archlinux centos debian fedora gentoo opensuse oraclelinux nix ubuntu; do
 target=$1
@@ -18,7 +18,7 @@ runs:
 EOF
 
 ### Generate the Dockerfile
-mainlibs="m4 git rsync patch tar unzip bzip2 make wget"
+mainlibs="m4 git rsync tar unzip bzip2 make wget"
 ocaml="ocaml ocaml-compiler-libs"
 
 OCAML_CONSTRAINT=''
@@ -108,6 +108,7 @@ EOF
     mainlibs=${mainlibs/m4/gnum4}
     mainlibs=${mainlibs/make/gnumake}
     mainlibs=${mainlibs/tar/}
+    mainlibs=${mainlibs/git/}
     mainlibs=$(echo "$mainlibs" | sed -E 's/([[:alnum:]]+)/nixpkgs.\1/g')
     additionallibs="gcc diffutils getconf gnused gawk"
     additionallibs=$(echo "$additionallibs" | sed -E 's/([[:alnum:]]+)/nixpkgs.\1/g')
