@@ -214,7 +214,7 @@ let preprocess_dot_install st nv build_dir =
       OpamFilename.in_dir build_dir @@ fun () ->
       log "Installing %s.\n" (OpamPackage.to_string nv);
       let warnings =
-        OpamStd.List.filter_map (fun install -> install warning) installs
+        List.filter_map (fun install -> install warning) installs
       in
       if warnings <> [] then
         (let install_f = OpamPath.Switch.install root st.switch nv.name in
@@ -367,18 +367,20 @@ let prepare_package_build env opam nv dir =
 
   let apply_patches ?(dryrun=false) () =
     let patch base =
-      if dryrun then Done None else
-        OpamFilename.patch
-          (dir // OpamFilename.Base.to_string base) dir
+      if dryrun then
+        Ok []
+      else
+        OpamFilename.patch ~allow_unclean:true
+          (`Patch_file (dir // OpamFilename.Base.to_string base)) dir
     in
     let rec aux = function
-      | [] -> Done []
+      | [] -> []
       | (patchname,filter)::rest ->
         if OpamFilter.opt_eval_to_bool env filter then
           (print_apply patchname;
-           patch patchname @@+ function
-           | None -> aux rest
-           | Some err -> aux rest @@| fun e -> (patchname, err) :: e)
+           match patch patchname with
+           | Ok _  -> aux rest
+           | Error e -> (patchname, e) :: aux rest)
         else aux rest
     in
     aux patches
@@ -390,63 +392,57 @@ let prepare_package_build env opam nv dir =
   in
   if OpamStateConfig.(!r.dryrun) || OpamClientConfig.(!r.fake) then
     (List.iter print_subst (OpamFile.OPAM.substs opam);
-     apply_patches ~dryrun:true ()) @@| fun _ -> None
+     let _ : _ list = apply_patches ~dryrun:true () in
+     None)
   else
-  let subst_errs =
-    OpamFilename.in_dir dir  @@ fun () ->
-    List.fold_left (fun errs f ->
-        try
-          print_subst f;
-          OpamFilter.expand_interpolations_in_file env f;
-          errs
-        with e -> (f, e)::errs)
-      [] subst_patches
-  in
-
-  (* Apply the patches *)
-  let text =
-    OpamProcess.make_command_text (OpamPackage.Name.to_string nv.name) "patch"
-  in
-  OpamProcess.Job.with_text text (apply_patches ())
-  @@+ fun patching_errors ->
-
-  (* Substitute the configuration files. We should be in the right
-     directory to get the correct absolute path for the
-     substitution files (see [OpamFilter.expand_interpolations_in_file] and
-     [OpamFilename.of_basename]. *)
-  let subst_errs =
-    OpamFilename.in_dir dir @@ fun () ->
-    List.fold_left (fun errs f ->
-        try
-          print_subst f;
-          OpamFilter.expand_interpolations_in_file env f;
-          errs
-        with e -> (f, e)::errs)
-      subst_errs subst_others
-  in
-  if patching_errors <> [] || subst_errs <> [] then
-    let msg =
-      (if patching_errors <> [] then
-         Printf.sprintf "These patches didn't apply at %s:\n%s"
-           (OpamFilename.Dir.to_string dir)
-           (OpamStd.Format.itemize
-              (fun (f,err) ->
-                 Printf.sprintf "%s: %s"
-                   (OpamFilename.Base.to_string f) (Printexc.to_string err))
-              patching_errors)
-       else "") ^
-      (if subst_errs <> [] then
-         Printf.sprintf "String expansion failed for these files:\n%s"
-           (OpamStd.Format.itemize
-              (fun (b,err) ->
-                 Printf.sprintf "%s.in: %s" (OpamFilename.Base.to_string b)
-                   (Printexc.to_string err))
-           subst_errs)
-       else "")
+    let subst_errs =
+      OpamFilename.in_dir dir  @@ fun () ->
+      List.fold_left (fun errs f ->
+          try
+            print_subst f;
+            OpamFilter.expand_interpolations_in_file env f;
+            errs
+          with e -> (f, e)::errs)
+        [] subst_patches
     in
-    Done (Some (Failure msg))
-  else
-    Done None
+    let patching_errors = apply_patches () in
+    (* Substitute the configuration files. We should be in the right
+       directory to get the correct absolute path for the
+       substitution files (see [OpamFilter.expand_interpolations_in_file] and
+       [OpamFilename.of_basename]. *)
+    let subst_errs =
+      OpamFilename.in_dir dir @@ fun () ->
+      List.fold_left (fun errs f ->
+          try
+            print_subst f;
+            OpamFilter.expand_interpolations_in_file env f;
+            errs
+          with e -> (f, e)::errs)
+        subst_errs subst_others
+    in
+    if patching_errors <> [] || subst_errs <> [] then
+      let msg =
+        (if patching_errors <> [] then
+           Printf.sprintf "These patches didn't apply at %s:\n%s"
+             (OpamFilename.Dir.to_string dir)
+             (OpamStd.Format.itemize
+                (fun (f,err) ->
+                   Printf.sprintf "%s: %s"
+                     (OpamFilename.Base.to_string f) (Printexc.to_string err))
+                patching_errors)
+         else "") ^
+        (if subst_errs <> [] then
+           Printf.sprintf "String expansion failed for these files:\n%s"
+             (OpamStd.Format.itemize
+                (fun (b,err) ->
+                   Printf.sprintf "%s.in: %s" (OpamFilename.Base.to_string b)
+                     (Printexc.to_string err))
+                subst_errs)
+         else "")
+      in
+      Some (Failure msg)
+    else
+      None
 
 let prepare_package_source st nv dir =
   log "prepare_package_source: %a at %a"
@@ -480,44 +476,66 @@ let prepare_package_source st nv dir =
     let extra_files =
       let extra_files =
         OpamFile.OPAM.get_extra_files
-          ~repos_roots:(OpamRepositoryState.get_root st.switch_repos)
+          ~get_repo_files:(OpamRepositoryState.get_repo_files st.switch_repos)
           opam
       in
       if extra_files <> [] then extra_files else
-      match OpamFile.OPAM.extra_files opam with
-      | None -> []
-      | Some xs ->
-        (* lookup in switch-local hashmap overlay *)
-        let extra_files_dir =
-          OpamPath.Switch.extra_files_dir st.switch_global.root st.switch
-        in
-        OpamStd.List.filter_map (fun (base, hash) ->
-            let src =
-              OpamFilename.create extra_files_dir
-                (OpamFilename.Base.of_string (OpamHash.contents hash))
-            in
-            if OpamFilename.exists src then
-              Some (src, base, hash)
-            else None)
-          xs
+        match OpamFile.OPAM.extra_files opam with
+        | None -> []
+        | Some xs ->
+          (* lookup in switch-local hashmap overlay *)
+          let extra_files_dir =
+            OpamPath.Switch.extra_files_dir st.switch_global.root st.switch
+          in
+          List.map (fun (base, hash) ->
+              let content =
+                let src =
+                  OpamFilename.create extra_files_dir
+                    (OpamFilename.Base.of_string (OpamHash.contents hash))
+                in
+                if OpamFilename.exists src then
+                  Some (lazy (OpamFilename.read src))
+                else
+                  None
+              in
+              (base, content, hash))
+            xs
     in
-    let bad_hash =
-      OpamStd.List.filter_map (fun (src, base, hash) ->
-          if OpamHash.check_file (OpamFilename.to_string src) hash then
-            (OpamFilename.copy ~src ~dst:(OpamFilename.create dir base); None)
-          else
-            Some src) extra_files
+    let bad_hash, missing =
+      List.fold_left (fun (bad_hash, missing) (base, content, hash) ->
+          match content with
+          | None -> bad_hash, (base::missing)
+          | Some (lazy content) when OpamHash.check_string content hash ->
+            OpamFilename.write (OpamFilename.create dir base) content;
+            bad_hash, missing
+          | Some _ ->
+            (base::bad_hash), missing)
+        ([], []) extra_files
     in
-    if bad_hash = [] then None else
-      Some (Failure
-              (Printf.sprintf "Bad hash for %s"
-                 (OpamStd.Format.itemize OpamFilename.to_string bad_hash)));
+    let bad_hash_msg bad_hash =
+      Printf.sprintf "%s: Bad hash for extra-file\n%s"
+        (OpamPackage.to_string nv)
+        (OpamStd.Format.itemize OpamFilename.Base.to_string bad_hash)
+    in
+    let missing_msg missing =
+      Printf.sprintf "%s: Missing extra-file for\n%s"
+        (OpamPackage.to_string nv)
+        (OpamStd.Format.itemize OpamFilename.Base.to_string missing)
+    in
+    match bad_hash, missing with
+    | [], [] -> None
+    | _::_ as bad_hash, [] ->
+      Some (Failure (bad_hash_msg bad_hash))
+    | [], (_::_ as missing) ->
+      Some (Failure (missing_msg missing))
+    | bad_hash, missing ->
+      Some (Failure (bad_hash_msg bad_hash ^ "\n" ^ missing_msg missing))
   in
   OpamFilename.mkdir dir;
   get_extra_sources_job @@+ function Some _ as err -> Done err | None ->
     check_extra_files |> function Some _ as err -> Done err | None ->
       let opam = OpamSwitchState.opam st nv in
-      prepare_package_build (OpamPackageVar.resolve ~opam st) opam nv dir
+      Done (prepare_package_build (OpamPackageVar.resolve ~opam st) opam nv dir)
 
 let compilation_env t opam =
   let build_env =
@@ -618,7 +636,7 @@ let get_wrapper t opam wrappers ?local getter =
   in
   OpamFilter.commands (OpamPackageVar.resolve ~local:local_env ~opam t)
     (getter wrappers) |>
-  OpamStd.List.filter_map (function
+  List.filter_map (function
       | [] -> None
       | cmd::args -> Some (cmd, args))
 
@@ -638,7 +656,7 @@ let make_command st opam ?dir ?text_command (cmd, args) =
   let nv = OpamFile.OPAM.package opam in
   let name = OpamPackage.name_to_string nv in
   let env = OpamTypesBase.env_array (compilation_env st opam) in
-  let dir = OpamStd.Option.map OpamFilename.Dir.to_string dir in
+  let dir = Stdlib.Option.map OpamFilename.Dir.to_string dir in
   let text =
     let cmd, args = OpamStd.Option.default (cmd, args) text_command in
     OpamProcess.make_command_text name ~args cmd
@@ -666,8 +684,7 @@ let make_command st opam ?dir ?text_command (cmd, args) =
           let rev = OpamProcess.Job.run (OpamRepository.revision src u) in
           Printf.sprintf "pinned(%s%s)"
             (OpamUrl.to_string_w_subpath (OpamFile.URL.subpath url) u)
-            (OpamStd.Option.to_string
-               (fun r -> "#"^OpamPackage.Version.to_string r) rev)
+            (OpamStd.Option.to_string (fun r -> "#"^r) rev)
       else
         match
           OpamRepositoryState.find_package_opt st.switch_repos
@@ -702,7 +719,7 @@ let remove_commands t nv =
   | Some opam ->
     OpamFilter.commands (OpamPackageVar.resolve ~opam t)
       (OpamFile.OPAM.remove opam) |>
-    OpamStd.List.filter_map
+    List.filter_map
       (function [] -> None | cmd::args -> Some (cmd,args))
 
 (* Testing wether a package removal will be a NOOP. *)
@@ -817,7 +834,7 @@ let remove_package_aux
       | some -> some
     in
     let title = Printf.sprintf "While removing %s" (OpamPackage.to_string nv) in
-    OpamStd.Option.iter
+    Stdlib.Option.iter
       (OpamDirTrack.revert ~title ~verbose:(not silent) ?force
          (OpamPath.Switch.root root t.switch))
       changes
@@ -825,13 +842,16 @@ let remove_package_aux
 
   (* Run the remove script *)
   let build_dir =
-    OpamStd.Option.default_map
-      (OpamFilename.opt_dir
-        (OpamPath.Switch.remove root t.switch nv))
-       build_dir
+    match build_dir with
+    | Some build_dir -> build_dir
+    | None ->
+      let dir = OpamPath.Switch.remove root t.switch nv in
+      if not (OpamFilename.exists_dir dir) then
+        OpamFilename.mkdir dir;
+      dir
   in
   let wrappers = get_wrappers t in
-  let mk_cmd = make_command t opam ?dir:build_dir in
+  let mk_cmd = make_command t opam ~dir:build_dir in
   OpamProcess.Job.of_fun_list ~keep_going:true
     (List.map (fun cmd () -> mk_cmd cmd)
        (get_wrapper t opam wrappers OpamFile.Wrappers.pre_remove))
@@ -894,10 +914,7 @@ let cleanup_package_artefacts t nv =
   let remove_dir = OpamPath.Switch.remove t.switch_global.root t.switch nv in
   if OpamFilename.exists_dir remove_dir then OpamFilename.rmdir remove_dir;
   let dev_dir = OpamSwitchState.source_dir t nv in
-  if OpamPackage.Set.mem nv t.installed then
-    (if not (OpamSwitchState.is_dev_package t nv) then
-       OpamFilename.rmdir dev_dir)
-  else
+  if not (OpamPackage.Set.mem nv t.installed) then
     (log "Removing the local metadata";
      OpamSwitchAction.remove_metadata t (OpamPackage.Set.singleton nv);
      if not (OpamPackage.Set.mem nv t.pinned) then
@@ -940,7 +957,7 @@ let build_package t ?(test=false) ?(doc=false) ?(dev_setup=false) build_dir nv =
        OpamFilter.commands (OpamPackageVar.resolve ~opam t)
          (OpamFile.OPAM.deprecated_build_doc opam)
      else [])
-    |> OpamStd.List.filter_map (function
+    |> List.filter_map (function
         | [] -> None
         | cmd::args -> Some (cmd, args))
   in
@@ -1001,7 +1018,7 @@ let install_package t ?(test=false) ?(doc=false) ?(dev_setup=false) ?build_dir
     OpamFilter.commands
       (OpamPackageVar.resolve ~opam
          ~local:(local_vars ~test ~doc ~dev_setup) t) |>
-    OpamStd.List.filter_map
+    List.filter_map
       (function [] -> None | cmd::args -> Some (cmd, args))
   in
   let name = OpamPackage.name_to_string nv in
@@ -1071,7 +1088,7 @@ let install_package t ?(test=false) ?(doc=false) ?(dev_setup=false) ?build_dir
     let local =
       let added =
         let open OpamDirTrack in
-        OpamStd.List.filter_map (function
+        List.filter_map (function
             | name, (Added _|Contents_changed _|Kind_changed _) -> Some name
             | _ -> None)
           (OpamStd.String.Map.bindings changes)
