@@ -12,17 +12,37 @@
 open OpamTypes
 open OpamProcess.Job.Op
 open OpamStateTypes
-open Cmdliner
+open OpamCmdliner
 
-type command = unit Cmdliner.Term.t * Cmdliner.Cmd.info
+type command = unit OpamCmdliner.Term.t * OpamCmdliner.Cmd.info
 
-let checked_repo_root () =
+let repo_version_lt repo_root v =
+  let v' =
+    let open OpamStd.Option.Op in
+    (OpamFile.Repo.read_opt
+       (OpamRepositoryPath.repo repo_root)
+     >>= OpamFile.Repo.opam_version)
+    +! OpamAdminRepoUpgrade.upgradefrom_version
+  in
+  if OpamVersion.compare v v' > 0 then Some v' else None
+
+let checked_repo_root ?(check=true) () =
   let repo_root = OpamFilename.cwd () in
   if not (OpamFilename.exists_dir (OpamRepositoryPath.packages_dir repo_root))
   then
     OpamConsole.error_and_exit `Bad_arguments
       "No repository found in current directory.\n\
        Please make sure there is a \"packages%s\" directory" OpamArg.dir_sep;
+  (if check then
+     match repo_version_lt repo_root
+             OpamAdminRepoUpgrade.upgradeto_version with
+     | Some v ->
+       OpamConsole.warning
+         "The repository is at version %s, \
+          please consider upgrading to %s with 'opam admin upgrade'"
+         (OpamVersion.to_string v)
+         (OpamVersion.to_string OpamAdminRepoUpgrade.upgradeto_version)
+     | None -> ());
   repo_root
 
 let global_options cli =
@@ -76,7 +96,7 @@ let index_command cli =
   in
   let cmd global_options urls_txt () =
     OpamArg.apply_global_options cli global_options;
-    let repo_root = checked_repo_root ()  in
+    let repo_root = checked_repo_root () in
     let repo_file = OpamRepositoryPath.repo repo_root in
     let repo_def =
       match OpamFile.Repo.read_opt repo_file with
@@ -131,7 +151,7 @@ let cache_urls repo_root repo_def =
     |> OpamFile.Config.dl_cache
   in
   let repo_dl_cache =
-    OpamStd.List.filter_map (fun rel ->
+    List.filter_map (fun rel ->
         if OpamStd.String.contains ~sub:"://" rel
         then OpamUrl.parse_opt ~handle_suffix:false rel
         else Some OpamUrl.Op.(OpamUrl.of_string
@@ -182,7 +202,7 @@ let package_files_to_cache repo_root cache_dir cache_urls
         | Some m ->
           OpamPackage.Map.update nv (fun l -> m::l) [] errors
         | None ->
-          OpamStd.Option.iter (fun link_dir ->
+          Stdlib.Option.iter (fun link_dir ->
               let name =
                 OpamStd.Option.default
                   (OpamUrl.basename (OpamFile.URL.url urlf))
@@ -271,7 +291,8 @@ let cache_command cli =
 
     let cache_dir_url = OpamFilename.remove_prefix_dir repo_root cache_dir in
     if not no_repo_update then
-      if not (List.mem cache_dir_url (OpamFile.Repo.dl_cache repo_def)) then
+      if not (OpamStd.List.mem String.equal
+                cache_dir_url (OpamFile.Repo.dl_cache repo_def)) then
         (OpamConsole.msg "Adding %s to %s...\n"
            cache_dir_url (OpamFile.to_string repo_file);
          OpamFile.Repo.write repo_file
@@ -628,7 +649,7 @@ let add_hashes_command cli =
              @@| function
              | Result () | Up_to_date () ->
                OpamHash.compute ~kind (OpamFilename.to_string f)
-               |> OpamStd.Option.some
+               |> Stdlib.Option.some
              | Not_available _ -> None)
       in
       (match h with
@@ -671,7 +692,9 @@ let add_hashes_command cli =
             let hashes = OpamFile.URL.checksum urlf in
             let hashes =
               if replace then
-                List.filter (fun h -> List.mem (OpamHash.kind h) hash_types)
+                List.filter (fun h ->
+                    OpamStd.List.mem OpamHash.equal_kind
+                      (OpamHash.kind h) hash_types)
                   hashes
               else hashes
             in
@@ -756,9 +779,11 @@ let upgrade_command cli =
   let cmd global_options clear_cache create_mirror () =
     OpamArg.apply_global_options cli global_options;
     if clear_cache then OpamAdminRepoUpgrade.clear_cache ()
-    else match create_mirror with
+    else
+      let repo_root = checked_repo_root ~check:false () in
+      match create_mirror with
       | None ->
-        OpamAdminRepoUpgrade.do_upgrade (OpamFilename.cwd ());
+        OpamAdminRepoUpgrade.do_upgrade repo_root;
         if OpamFilename.exists (OpamFilename.of_string "index.tar.gz") ||
            OpamFilename.exists (OpamFilename.of_string "urls.txt")
         then
@@ -766,7 +791,7 @@ let upgrade_command cli =
             "Indexes need updating: you should now run:\n\
              \n\
             \  opam admin index"
-      | Some m -> OpamAdminRepoUpgrade.do_upgrade_mirror (OpamFilename.cwd ()) m
+      | Some m -> OpamAdminRepoUpgrade.do_upgrade_mirror repo_root m
   in
   OpamArg.mk_command  ~cli OpamArg.cli_original command ~doc ~man
     Term.(const cmd $ global_options cli $
@@ -811,7 +836,7 @@ let lint_command cli =
   in
   let cmd global_options short list incl excl ign warn_error () =
     OpamArg.apply_global_options cli global_options;
-    let repo_root = OpamFilename.cwd () in
+    let repo_root = checked_repo_root () in
     if not (OpamFilename.exists_dir OpamFilename.Op.(repo_root / "packages"))
     then
         OpamConsole.error_and_exit `Bad_arguments
@@ -822,10 +847,13 @@ let lint_command cli =
       OpamPackage.Map.fold (fun nv prefix ret ->
           let opam_file = OpamRepositoryPath.opam repo_root prefix nv in
           let w, _ = OpamFileTools.lint_file ~handle_dirname:true opam_file in
-          if List.exists (fun (n,_,_) -> List.mem n ign) w then ret else
+          if List.exists (fun (n,_,_) -> OpamStd.List.mem Int.equal n ign) w then
+            ret
+          else
           let w =
             List.filter (fun (n,_,_) ->
-                (incl = [] || List.mem n incl) && not (List.mem n excl))
+                (incl = [] || OpamStd.List.mem Int.equal n incl) &&
+                not (OpamStd.List.mem Int.equal n excl))
               w
           in
           if w <> [] then
@@ -1123,6 +1151,7 @@ let list_command cli =
       global_options package_selection disjunction state_selection
       package_listing env packages () =
     OpamArg.apply_global_options cli global_options;
+    let repo_root = checked_repo_root () in
     let format =
       let force_all_versions =
         match packages with
@@ -1149,7 +1178,7 @@ let list_command cli =
               List.map (fun x -> Atom x) package_selection);
       ]
     in
-    let st = get_virtual_switch_state (OpamFilename.cwd ()) env in
+    let st = get_virtual_switch_state repo_root env in
     if not format.OpamListCommand.short && filter <> OpamFormula.Empty then
       OpamConsole.msg "# Packages matching: %s\n"
         (OpamListCommand.string_of_formula filter);
@@ -1190,7 +1219,7 @@ let filter_command cli =
       global_options package_selection disjunction state_selection env
       remove dryrun packages () =
     OpamArg.apply_global_options cli global_options;
-    let repo_root = OpamFilename.cwd () in
+    let repo_root = checked_repo_root () in
     let pattern_selector = OpamListCommand.pattern_selector packages in
     let join =
       if disjunction then OpamFormula.ors else OpamFormula.ands
@@ -1378,7 +1407,7 @@ let help =
     | None       -> `Help (`Pager, None)
     | Some topic ->
       let topics = "topics" :: cmds in
-      let conv, _ = Cmdliner.Arg.enum (List.rev_map (fun s -> (s, s)) topics) in
+      let conv, _ = OpamCmdliner.Arg.enum (List.rev_map (fun s -> (s, s)) topics) in
       match conv topic with
       | `Error e -> `Error (false, e)
       | `Ok t when t = "topics" ->
