@@ -16,6 +16,8 @@ module O = OpamFile.OPAM
 
 let upgradeto_version_string = "2.0"
 let upgradeto_version = OpamVersion.of_string upgradeto_version_string
+let upgradefrom_version_string = "1.2"
+let upgradefrom_version = OpamVersion.of_string upgradefrom_version_string
 
 let ocaml_wrapper_pkgname = OpamPackage.Name.of_string "ocaml"
 let ocaml_official_pkgname = OpamPackage.Name.of_string "ocaml-base-compiler"
@@ -178,7 +180,7 @@ let do_upgrade repo_root =
     let () =
       OpamFile.Lines.read_opt cache_file +! [] |> List.iter @@ function
       | [url; md5] ->
-        OpamStd.Option.iter
+        Stdlib.Option.iter
           (fun url -> Hashtbl.add url_md5 url (OpamHash.of_string md5))
           (OpamUrl.parse_opt ~handle_suffix:false url)
       | _ -> failwith "Bad cache, run 'opam admin upgrade --clear-cache'"
@@ -332,7 +334,7 @@ let do_upgrade repo_root =
 
       (* cleanup *)
       OpamFilename.remove comp_file;
-      OpamStd.Option.iter OpamFilename.remove descr_file;
+      Stdlib.Option.iter OpamFilename.remove descr_file;
       OpamFilename.rmdir_cleanup (OpamFilename.dirname comp_file);
       OpamConsole.status_line
         "Compiler %s successfully converted to package %s"
@@ -420,7 +422,8 @@ let do_upgrade repo_root =
       let opam0 = OpamFile.OPAM.read opam_file in
       OpamFile.OPAM.print_errors ~file:opam_file opam0;
       let nv = OpamFile.OPAM.package opam0 in
-      if not (List.mem nv.name ocaml_package_names) &&
+      if not (OpamStd.List.mem OpamPackage.Name.equal
+                nv.name ocaml_package_names) &&
          not (OpamPackage.Name.Set.mem nv.name all_base_packages) then
         let opam = OpamFileTools.add_aux_files ~files_subdir_hashes:true opam0 in
         let opam =
