@@ -11,7 +11,7 @@
 
 open OpamTypes
 open OpamTypesBase
-open Cmdliner
+open OpamCmdliner
 open OpamStd.Op
 
 include OpamArgTools
@@ -87,6 +87,8 @@ let environment_variables =
   let open OpamStd.Config in
   let core =
     let open OpamCoreConfig.E in [
+      "AUTOANSWER", cli_from cli2_5, (fun v -> AUTOANSWER (auto_answer v)),
+      "internal use only.";
       "COLOR", cli_original, (fun v -> COLOR (env_when v)),
       "when set to $(i,always) or $(i,never), sets a default value for the \
        `--color' option.";
@@ -212,7 +214,8 @@ let environment_variables =
       "CURL", cli_original, (fun v -> CURL (env_string v)),
       "can be used to select a given 'curl' program. See $(i,OPAMFETCH) for \
        more options.";
-      "FETCH", cli_original, (fun v -> FETCH (env_string v)),
+      "FETCH", cli_original, (fun v ->
+        FETCH (Option.map OpamShellCommand.of_string (env_string v))),
       "specifies how to download files: either `wget', `curl' or a custom \
        command where variables $(b,%{url}%), $(b,%{out}%), $(b,%{retry}%), \
        $(b,%{compress}%) and $(b,%{checksum}%) will be replaced. Overrides the \
@@ -328,7 +331,7 @@ let scrubbed_environment_variables =
     else
       Some ("OPAM" ^ name)
   in
-    OpamStd.List.filter_map f environment_variables
+  List.filter_map f environment_variables
 
 let doc_opam_env_variables, init_opam_env_variabes =
   env_with_cli environment_variables
@@ -473,7 +476,7 @@ type global_options = {
   cli : OpamCLIVersion.t;
 }
 
-(* The --cli passed by cmdliner is ignored (it's only there for --help) *)
+(* The --cli passed by opam-core.cmdliner is ignored (it's only there for --help) *)
 let create_global_options
     git_version debug debug_level verbose quiet color opt_switch
     yes confirm_level
@@ -518,7 +521,7 @@ let apply_global_options cli o =
       o.external_solver >>| fun s -> lazy (OpamCudfSolver.solver_of_string s)
   in
   let solver_prefs = o.solver_preferences >>| fun p -> lazy (Some p) in
-  let yes = OpamStd.Option.(map some o.yes) in
+  let yes = Stdlib.Option.map Stdlib.Option.some o.yes in
   init_opam_env_variabes cli;
   OpamClientConfig.opam_init
     (* - format options - *)
@@ -620,7 +623,7 @@ let apply_global_options cli o =
             | Some { pelem = Ident "os-distribution"; _},
               { pelem = String "msys2"; _}::_  ->
               let cygbin =
-                OpamStd.Option.map Filename.dirname
+                Stdlib.Option.map Filename.dirname
                   (OpamSystem.resolve_command "cygcheck")
               in
               OpamCoreConfig.update ?cygbin ()
@@ -858,7 +861,7 @@ let atom =
 let atom_or_local =
   let parse str =
     if OpamStd.String.contains ~sub:Filename.dir_sep str ||
-       OpamStd.String.starts_with ~prefix:"." str
+       OpamCompat.String.starts_with ~prefix:"." str
     then
       if OpamFilename.(exists (of_string str)) then
         `Ok (`Filename (OpamFilename.of_string str))
@@ -1006,7 +1009,7 @@ let enum_with_default sl: 'a Arg.converter =
 
 let opamlist_column =
   let parse str =
-    if OpamStd.String.ends_with ~suffix:":" str then
+    if OpamCompat.String.ends_with ~suffix:":" str then
       let fld = OpamStd.String.remove_suffix ~suffix:":" str in
       `Ok (OpamListCommand.Field fld)
     else
