@@ -12,7 +12,7 @@
 (** Command-line argument parsers and helpers *)
 
 open OpamTypes
-open Cmdliner
+open OpamCmdliner
 
 (** {2 Helpers and argument constructors} *)
 
@@ -26,6 +26,7 @@ val cli2_1: OpamCLIVersion.t
 val cli2_2: OpamCLIVersion.t
 val cli2_3: OpamCLIVersion.t
 val cli2_4: OpamCLIVersion.t
+val cli2_5: OpamCLIVersion.t
 
 (* [cli_from ?platform ?experimental since] validity flag since [since], and no
    removal version. If [experimental] is true, it is marked as is (warning and
@@ -369,7 +370,7 @@ val mk_command:
 val mk_command_ret:
   cli:OpamCLIVersion.Sourced.t -> validity -> string -> doc:string ->
   man:Manpage.block list -> (unit -> unit Term.ret) Term.t -> command
-  (* Same as {!mk_command} but [term] returns a [Cmdliner.Term.ret] *)
+  (* Same as {!mk_command} but [term] returns a [OpamCmdliner.Term.ret] *)
 
 (** {2 Documentation} *)
 
