@@ -263,7 +263,7 @@ let autopin_aux st ?quiet ?recurse ?subpath ?locked
     atoms, to_pin, OpamPackage.Set.empty, OpamPackage.Set.empty
   else
   let pinning_dirs =
-    OpamStd.List.filter_map (function
+    List.filter_map (function
         | `Dirname d -> Some OpamFilename.SubPath.(d /? subpath)
         | _ -> None)
       atom_or_local_list
@@ -287,7 +287,7 @@ let autopin_aux st ?quiet ?recurse ?subpath ?locked
         in
         match OpamStd.Option.Op.( primary_url st nv >>= OpamUrl.local_dir) with
         | Some d ->
-          List.mem d pinning_dirs
+          OpamStd.List.mem OpamFilename.Dir.equal d pinning_dirs
         | None -> false)
       st.pinned
   in
@@ -325,7 +325,7 @@ let autopin_aux st ?quiet ?recurse ?subpath ?locked
                      opam
                  | Some _ -> opam
                in
-               OpamStd.Option.equal String.equal
+               Stdlib.Option.equal String.equal
                  locked (OpamFile.OPAM.locked opam)
                && OpamFile.OPAM.effectively_equal opam0 opam
              | None -> false)
@@ -500,7 +500,7 @@ let autopin st ?(simulate=false) ?quiet ?locked ?recurse ?subpath
     (* is pinned but no in already pinned because not same url *)
     List.fold_left (fun set nf ->
         match
-          OpamStd.Option.map
+          Stdlib.Option.map
             (fun nv -> OpamPackage.Set.mem nv already_pinned_set)
             (OpamPinned.package_opt st nf.pin_name)
         with
@@ -563,7 +563,8 @@ let check_and_revert_sandboxing root config =
         OpamInitDefaults.sandbox_wrappers
       |> List.flatten
     in
-    List.filter (fun cmd -> List.mem cmd init_sdbx_cmds)
+    List.filter (fun cmd ->
+        OpamStd.List.mem OpamTypesBase.command_equal cmd init_sdbx_cmds)
       OpamFile.Wrappers.(wrap_build w @ wrap_install w @ wrap_remove w)
   in
   let env = fun v ->
@@ -604,7 +605,8 @@ let check_and_revert_sandboxing root config =
     if working_or_noop then config else
     let wrappers =
       let filter sdbx_cmd =
-        List.filter (fun cmd_l -> not (List.mem cmd_l sdbx_cmd))
+        List.filter (fun cmd_l ->
+            not (OpamStd.List.mem OpamTypesBase.command_equal cmd_l sdbx_cmd))
       in
       List.fold_left OpamFile.Wrappers.(fun w -> function
           | `build sdbx_build ->
