@@ -47,7 +47,6 @@ let dragonflybsd_filter = os_filter "dragonfly"
 let not_bsd_filter =
   FNot (FOr (FOr (openbsd_filter, netbsd_filter),
              FOr (freebsd_filter, dragonflybsd_filter)))
-let win32_filter = os_filter "win32"
 let not_win32_filter =
   FOp (FIdent ([], OpamVariable.of_string "os", None), `Neq, FString "win32")
 let sandbox_filter = FOr (linux_filter, macos_filter)
@@ -55,8 +54,6 @@ let sandbox_filter = FOr (linux_filter, macos_filter)
 let gtar_filter = openbsd_filter
 let tar_filter = FNot gtar_filter
 
-let getconf_filter = FNot (FOr (win32_filter, freebsd_filter))
-
 let sandbox_wrappers =
   let cmd t = [
     CString "%{hooks}%/sandbox.sh", None;
@@ -99,8 +96,7 @@ let req_dl_tools () =
   let open OpamStd.Option.Op in
   let cmd =
     (OpamRepositoryConfig.E.fetch_t ()
-     >>= fun s ->
-     match OpamStd.String.split s ' ' with
+     >>= function
      | c::_ -> Some c
      | _ -> None)
     >>+ fun () -> OpamRepositoryConfig.E.curl_t ()
@@ -113,8 +109,8 @@ let req_dl_tools () =
 let dl_tool () =
   let open OpamStd.Option.Op in
   (OpamRepositoryConfig.E.fetch_t ()
-   >>+ fun () -> OpamRepositoryConfig.E.curl_t ())
-  >>| fun cmd -> [(CString cmd), None]
+   >>+ fun () -> Option.map (fun x -> [x]) (OpamRepositoryConfig.E.curl_t ()))
+  >>| fun cmd -> List.map (fun x -> (CString x, None)) cmd
 
 let recommended_tools () =
   let make = OpamStateConfig.(Lazy.force !r.makecmd) in
@@ -129,7 +125,6 @@ let required_tools ~sandboxing () =
     ["tar"], None, Some tar_filter;
     ["gtar"], None, Some gtar_filter;
     ["unzip"], None, None;
-    ["getconf"], None, Some getconf_filter;
   ] @
   if sandboxing then [
     [bwrap_cmd], Some (bwrap_string()), Some bwrap_filter;
