@@ -348,7 +348,7 @@ let apply_selector ~base st = function
       base
   | Tag t ->
     OpamPackage.Set.filter (fun nv ->
-        get_opam st nv |> List.mem t @* OpamFile.OPAM.tags)
+        get_opam st nv |> List.exists (String.equal t) @* OpamFile.OPAM.tags)
       base
   | From_repository repos ->
     let rt = st.switch_repos in
@@ -358,7 +358,8 @@ let apply_selector ~base st = function
         let packages =
           OpamPackage.keys (OpamRepositoryName.Map.find r rt.repo_opams)
         in
-        if List.mem r repos then OpamPackage.Set.union packages (aux rl)
+        if List.exists (OpamRepositoryName.equal r) repos
+        then OpamPackage.Set.union packages (aux rl)
         else OpamPackage.Set.diff (aux rl) packages
     in
     aux (OpamSwitchState.repos_list st)
@@ -383,13 +384,16 @@ let apply_selector ~base st = function
              OpamStd.String.Map.exists
                (fun f -> function
                   | OpamDirTrack.Removed -> false
-                  | _ -> rel_name = f)
+                  | _ -> rel_name = (f : string))
                changes)
            (OpamFilename.files (OpamPath.Switch.install_dir root switch))
        in
        let selections =
-         if switch = st.switch then OpamSwitchState.selections st
-         else OpamSwitchState.load_selections st.switch_global switch
+         if OpamSwitch.equal switch st.switch then
+           OpamSwitchState.selections st
+         else
+           OpamSwitchState.load_selections ~lock_kind:`Lock_none
+             st.switch_global switch
        in
        List.fold_left (fun acc f ->
            let name =
@@ -496,16 +500,17 @@ let field_of_string ~raw =
     fun s -> Raw_field s
   else
   fun s ->
-    if OpamStd.String.ends_with ~suffix:":" s then
+    if OpamCompat.String.ends_with ~suffix:":" s then
       Raw_field (OpamStd.String.remove_suffix ~suffix:":" s)
     else
     try
       OpamStd.List.assoc String.equal s names_fields
     with Not_found ->
-    match OpamStd.List.find_opt (fun x -> s = x) opam_fields with
+    match List.find_opt (String.equal s) opam_fields with
     | Some f -> Field f
     | None -> OpamConsole.error_and_exit `Bad_arguments "No printer for %S" s
 
+(* NOTE: upon changes, please update the man page section in opamCommands.ml *)
 let version_color st nv =
   let installed = (* (in any switch) *)
     OpamGlobalState.installed_versions st.switch_global nv.name
@@ -520,7 +525,14 @@ let version_color st nv =
   in
   if OpamPackage.Set.mem nv st.installed then [`bold;`magenta] else
     (if OpamPackage.Map.mem nv installed then [`bold] else []) @
-    (if is_available nv then [] else [`crossed;`red])
+    (if is_available nv then
+       match OpamSwitchState.opam_opt st nv with
+       | Some opam when
+           OpamFile.OPAM.has_flag Pkgflag_AvoidVersion opam ||
+           OpamFile.OPAM.has_flag Pkgflag_Deprecated opam ->
+         [`gray]
+       | None | Some _ -> []
+     else [`crossed;`red])
 
 let mini_field_printer ?(prettify=false) ?(normalise=false) =
   let module OpamPrinter = OpamPrinter.FullPos in
@@ -559,7 +571,10 @@ let detail_printer ?prettify ?normalise ?(sort=false) st nv =
     (match OpamPinned.package_opt st nv.name with
      | Some nv ->
        let opam = get_opam st nv in
-       if Some opam = OpamPackage.Map.find_opt nv st.repos_package_index then
+       if
+         OpamStd.Option.equal_some OpamFile.OPAM.equal
+           opam (OpamPackage.Map.find_opt nv st.repos_package_index)
+       then
          Printf.sprintf "pinned to version %s"
            (OpamPackage.Version.to_string nv.version % [`blue])
        else
@@ -623,8 +638,7 @@ let detail_printer ?prettify ?normalise ?(sort=false) st nv =
       OpamSwitchState.url st nv >>| OpamFile.URL.url >>= fun url ->
       OpamSwitchState.source_dir st nv |>
       OpamFilename.opt_dir >>= fun srcdir ->
-      OpamProcess.Job.run (OpamRepository.revision srcdir url) >>|
-      OpamPackage.Version.to_string
+      OpamProcess.Job.run (OpamRepository.revision srcdir url)
     in
     OpamStd.Option.default "" hash_opt
   | Raw -> OpamFile.OPAM.write_to_string (get_opam st nv)
