@@ -24,7 +24,7 @@ let select_packages atom_locs st =
   else
     (let names = OpamPackage.names_of_packages packages in
      let missing =
-       OpamStd.List.filter_map (fun (n,vc) ->
+       List.filter_map (fun (n,vc) ->
            if OpamPackage.Name.Set.mem n names then None
            else Some (n,vc)) atoms
      in
@@ -124,11 +124,11 @@ let get_git_url url nv dir =
          (OpamUrl.to_string u);
      Some u)
   | _ ->
-    (OpamConsole.error "Can't retrieve remote informations for %s"
+    (OpamConsole.error "Remote branch not found for %s"
        (OpamPackage.to_string nv);
      None)
 
-let lock_opam ?(only_direct=false) st opam =
+let lock_opam ~only_direct ~keep_local st opam =
   let nv = OpamFile.OPAM.package opam in
   (* Depends *)
   let all_depends =
@@ -274,15 +274,33 @@ let lock_opam ?(only_direct=false) st opam =
          (OpamPackage.Name.Set.elements uninstalled_depopts))
   in
   let pin_depends =
+    let pin_depends =
+      let is_pin nv = OpamSwitchState.is_pinned st nv.name in
+      let pins map set =
+        OpamPackage.Map.fold (fun nv _ set ->
+            if is_pin nv then OpamPackage.Set.add nv set else set)
+          map set
+      in
+      OpamPackage.Set.filter is_pin all_depends
+      |> pins dev_depends_map
+      |> pins test_depends_map
+      |> pins doc_depends_map
+      |> pins dev_setup_depends_map
+    in
     OpamPackage.Set.fold (fun nv acc ->
-        if not (OpamSwitchState.is_pinned st nv.name) then acc else
         match OpamSwitchState.primary_url st nv with
         | None -> acc
         | Some u ->
           match OpamUrl.local_dir u with
+          | Some _ when keep_local ->
+            OpamConsole.note
+              "Dependency %s is pinned to local target %s, keeping it."
+              (OpamPackage.to_string nv) (OpamUrl.to_string u);
+            (nv, u) :: acc
           | Some d ->
             let local_warn () =
-              OpamConsole.warning "Dependency %s is pinned to local target %s"
+              OpamConsole.warning
+                "Dependency %s is pinned to local target %s, skipping"
                 (OpamPackage.to_string nv) (OpamUrl.to_string u);
               acc
             in
@@ -296,7 +314,7 @@ let lock_opam ?(only_direct=false) st opam =
                 | None -> local_warn ())
              | _ -> local_warn ())
           | None -> (nv, u) :: acc)
-      all_depends []
+      pin_depends []
     |> List.rev
   in
   opam
