@@ -102,7 +102,7 @@ let copy_files st opam =
   let name = OpamFile.OPAM.name opam in
   let files =
     OpamFile.OPAM.get_extra_files
-      ~repos_roots:(OpamRepositoryState.get_root st.switch_repos)
+      ~get_repo_files:(OpamRepositoryState.get_repo_files st.switch_repos)
       opam
   in
   if files = [] then
@@ -118,30 +118,31 @@ let copy_files st opam =
     OpamPath.Switch.Overlay.files st.switch_global.root st.switch name
   in
   let files =
-    List.fold_left (fun acc (src, rel_file, hash) ->
-        if not (OpamFilename.exists src) then
-          (OpamConsole.warning "Overlay file of %s %s not found, ignoring"
-             (OpamPackage.Name.to_string name)
-             (OpamFilename.to_string src);
-           acc)
-        else
-        let hash =
-          if not (OpamHash.check_file (OpamFilename.to_string src) hash) then
-            if OpamFormatConfig.(!r.strict) then
-              OpamConsole.error_and_exit `File_error
-                "Hash mismatch on %s %s (strict mode)"
-                (OpamPackage.Name.to_string name)
-                (OpamFilename.to_string src)
-            else
-              (OpamConsole.warning
-                 "Hash doesn't match for overlay file of %s %s, adjusted"
-                 (OpamPackage.Name.to_string name)
-                 (OpamFilename.to_string src);
-               OpamHash.compute (OpamFilename.to_string src))
-          else hash
-        in
-        OpamFilename.copy ~src ~dst:(OpamFilename.create destdir rel_file);
-        (rel_file, hash) :: acc)
+    List.fold_left (fun acc (rel_file, content, hash) ->
+        match content with
+        | None ->
+          OpamConsole.warning "Overlay file of %s %s not found, ignoring"
+            (OpamPackage.Name.to_string name)
+            (OpamFilename.Base.to_string rel_file);
+          acc
+        | Some (lazy content) ->
+          let hash =
+            if not (OpamHash.check_string content hash) then
+              if OpamFormatConfig.(!r.strict) then
+                OpamConsole.error_and_exit `File_error
+                  "Hash mismatch on %s %s (strict mode)"
+                  (OpamPackage.Name.to_string name)
+                  (OpamFilename.Base.to_string rel_file)
+              else
+                (OpamConsole.warning
+                   "Hash doesn't match for overlay file of %s %s, adjusted"
+                   (OpamPackage.Name.to_string name)
+                   (OpamFilename.Base.to_string rel_file);
+                 OpamHash.compute_from_string content)
+            else hash
+          in
+          OpamFilename.write (OpamFilename.create destdir rel_file) content;
+          (rel_file, hash) :: acc)
       [] files
   in
   OpamFile.OPAM.with_extra_files (List.rev files) opam
@@ -423,7 +424,7 @@ let rec handle_pin_depends st nv opam =
               (OpamConsole.colorise `bold (OpamPackage.to_string nv))
               (OpamConsole.colorise `underline (OpamUrl.to_string url)))
           extra_pins);
-     if OpamConsole.confirm "Pin and install them?" then
+     if OpamConsole.confirm ~name:"install-pin-depends" "Pin and install them?" then
        (let extra_pins =
           fetch_all_pins st (List.map (fun (nv, u) ->
               { pinned_name = OpamPackage.name nv;
@@ -438,7 +439,7 @@ let rec handle_pin_depends st nv opam =
             source_pin st pin.pinned_name ?version:pin.pinned_version
               (Some pin.pinned_url) ~ignore_extra_pins:true)
           st extra_pins)
-     else if OpamConsole.confirm
+     else if OpamConsole.confirm ~name:"ignore-pin-depends"
          "Try to install anyway, assuming `--ignore-pin-depends'?"
      then st else
        OpamStd.Sys.exit_because `Aborted)
@@ -469,7 +470,7 @@ and source_pin
       let cur_opam = OpamSwitchState.opam st nv in
       let cur_urlf = OpamFile.OPAM.url cur_opam in
       let no_changes =
-        target_url = OpamStd.Option.map OpamFile.URL.url cur_urlf &&
+        target_url = Stdlib.Option.map OpamFile.URL.url cur_urlf &&
         (version = Some cur_version || version = None)
       in
       if not (quiet && no_changes) then
@@ -496,7 +497,7 @@ and source_pin
                       registered in the current switch."
       (OpamPackage.Name.to_string name);
 
-  (match OpamStd.Option.map OpamFile.URL.url cur_urlf, target_url with
+  (match Stdlib.Option.map OpamFile.URL.url cur_urlf, target_url with
    | Some u, Some target when OpamUrl.(
        u.transport <> target.transport ||
        u.path <> target.path ||
@@ -765,13 +766,12 @@ let list st ~short =
         match url.OpamUrl.backend with
         | #OpamUrl.version_control ->
           let srcdir = OpamSwitchState.source_dir st nv in
-          let prefix, color, rev =
+          let color, rev =
             match OpamProcess.Job.run (OpamRepository.revision srcdir url) with
-            | None | exception _ ->
-              ("", `red, "error while fetching current revision")
-            | Some ver -> ("at ", `magenta, ver)
+            | None -> (`red, "error while fetching current revision")
+            | Some ver -> (`magenta, ver)
           in
-          Some (Printf.sprintf "(%s%s)" prefix (OpamConsole.colorise color rev))
+          Some (Printf.sprintf "(at %s)" (OpamConsole.colorise color (rev)))
         | _ -> None
       in
       [ OpamPackage.to_string nv;
@@ -794,7 +794,7 @@ let scan ~normalise ~recurse ?subpath url =
     OpamPinned.files_in_source_w_target
       ?locked:OpamStateConfig.(!r.locked)
       ~recurse ?subpath url dir
-    |> OpamStd.List.filter_map (fun nf ->
+    |> List.filter_map (fun nf ->
         let opam =
           OpamFile.OPAM.(safe_read nf.pin.pin_file
                          |> with_locked_opt nf.pin.pin_locked)
@@ -872,7 +872,7 @@ let scan ~normalise ~recurse ?subpath url =
     |> OpamConsole.print_table stdout ~sep:"  "
 
 let looks_like_normalised args =
-    List.for_all (fun s -> OpamStd.String.contains_char s scan_sep) args
+    List.for_all (fun s -> String.contains s scan_sep) args
 
 let parse_pins pins =
   let separator = Re.char scan_sep in
@@ -898,17 +898,17 @@ let parse_pins pins =
       Some Re.Group.{
           pinned_name = OpamPackage.Name.of_string @@ get groups 1;
           pinned_version =
-            OpamStd.Option.map OpamPackage.Version.of_string
+            Stdlib.Option.map OpamPackage.Version.of_string
             @@ OpamStd.Option.of_Not_found (get groups) 2;
           pinned_url = OpamUrl.parse @@ get groups 3;
           pinned_subpath =
-            OpamStd.Option.map OpamFilename.SubPath.of_string
+            Stdlib.Option.map OpamFilename.SubPath.of_string
             @@ OpamStd.Option.of_Not_found (get groups) 4;
           pinned_opam = None;
         }
     with Not_found | Failure _ -> None
   in
-  OpamStd.List.filter_map (fun str ->
+  List.filter_map (fun str ->
       let pin = get str in
       if pin = None then
         (OpamConsole.warning "Argument %S is not correct" str;
