@@ -48,7 +48,7 @@ let post_message ?(failed=false) st action =
         ["Note: This package is deprecated."]
       else
         []) @
-      OpamStd.List.filter_map (fun (message,filter) ->
+      List.filter_map (fun (message,filter) ->
           if OpamFilter.opt_eval_to_bool filter_env filter then
             Some (OpamFilter.expand_string ~default:(fun _ -> "")
                     filter_env message)
@@ -186,7 +186,7 @@ let check_availability ?permissive t set atoms =
             (OpamSwitchState.unavailable_reason
                ~default:"the package no longer exists"
                t f)) in
-  let errors = OpamStd.List.filter_map check_atom atoms in
+  let errors = List.filter_map check_atom atoms in
   if errors <> [] then
     (List.iter (OpamConsole.error "%s") errors;
      OpamStd.Sys.exit_because `Not_found)
@@ -485,16 +485,14 @@ let parallel_apply t
     let sources_needed =
       (* used to factorise fetches: creates [`Fetch] nodes with several
          packages that download once the archive and copies its content in
-         source directories. Handles only http and rsync backend with at least
-         one checksum. *)
+         source directories. Handles only http and rsync backends. *)
       let shared_source =
         OpamPackage.Set.fold (fun nv url_nvs ->
             match OpamSwitchState.url t nv with
             | Some url ->
-              let checksums = OpamFile.URL.checksum url in
               let url = OpamFile.URL.url url in
-              (match url.OpamUrl.backend, checksums with
-               | (`http | `rsync ) , _::_
+              (match url.OpamUrl.backend with
+               | (`http | `rsync )
                  when OpamFilename.is_archive
                      (OpamFilename.of_string url.OpamUrl.path) ->
                  OpamUrl.Map.update url
@@ -621,7 +619,7 @@ let parallel_apply t
             OpamAction.download_package t nv
           | _ ->
             let url =
-              match OpamStd.List.filter_map (OpamSwitchState.url t) nvs with
+              match List.filter_map (OpamSwitchState.url t) nvs with
               | u::_ as urls ->
                 let checksums =
                   List.map OpamFile.URL.checksum urls
@@ -650,7 +648,8 @@ let parallel_apply t
         try true, OpamPackage.Map.find nv inplace
         with Not_found ->
           let dir = OpamPath.Switch.build t.switch_global.root t.switch nv in
-          if not OpamClientConfig.(!r.reuse_build_dir) then
+          if not OpamClientConfig.(!r.reuse_build_dir) &&
+             not OpamStateConfig.(!r.dryrun) then
             OpamFilename.rmdir dir;
           false, dir
       in
@@ -661,10 +660,11 @@ let parallel_apply t
         OpamStateConfig.(!r.dev_setup) && found
       in
       let source_dir = source_dir nv in
-      (if OpamFilename.exists_dir source_dir
-       then (if not is_inplace then
-               OpamFilename.copy_dir ~src:source_dir ~dst:build_dir)
-       else OpamFilename.mkdir build_dir;
+      (if not OpamStateConfig.(!r.dryrun) then
+         if OpamFilename.exists_dir source_dir
+         then (if not is_inplace then
+                 OpamFilename.copy_dir ~src:source_dir ~dst:build_dir)
+         else OpamFilename.mkdir build_dir;
        OpamAction.prepare_package_source t nv build_dir @@+ function
        | Some exn -> store_time (); Done (`Exception exn)
        | None ->
@@ -729,10 +729,10 @@ let parallel_apply t
       let pools =
         (installs_removes, 1) ::
         (fetches, OpamStateConfig.(!r.dl_jobs)) ::
-        OpamStd.List.filter_map
+        List.filter_map
           (fun excl ->
              match
-               OpamStd.List.filter_map
+               List.filter_map
                  (fun nv ->
                     let act = `Build nv in
                     if PackageActionGraph.mem_vertex action_graph act
@@ -825,31 +825,32 @@ let parallel_apply t
   (* 2/ Display errors and finalize *)
 
   let save_installed_cache failed =
-    OpamSwitchState.Installed_cache.save
-      (OpamPath.Switch.installed_opams_cache t.switch_global.root t.switch)
-      (OpamPackage.Set.fold (fun nv opams ->
-           (* NOTE: We need to know whether an action was successful
-              or not to know which version of the opam file to store
-              in the case: the previous one if it failed, or the new
-              one if it succeeded. *)
-           let pkg_failed =
-             List.exists (function
-                 | `Fetch ps -> List.for_all (OpamPackage.equal nv) ps
-                 | `Build p | `Change (_, _, p) | `Install p
-                 | `Reinstall p | `Remove p -> OpamPackage.equal nv p)
-               failed
-           in
-           let add_to_opams opam =
-             let opam = OpamFile.OPAM.with_metadata_dir None opam in
-             OpamPackage.Map.add nv opam opams
-           in
-           if pkg_failed then
-             match OpamPackage.Map.find_opt nv t.installed_opams with
-             | None -> opams
-             | Some opam -> add_to_opams opam
-           else
-             add_to_opams (OpamSwitchState.opam t nv))
-          t.installed OpamPackage.Map.empty);
+    if not OpamStateConfig.(!r.dryrun) then
+      OpamSwitchState.Installed_cache.save
+        (OpamPath.Switch.installed_opams_cache t.switch_global.root t.switch)
+        (OpamPackage.Set.fold (fun nv opams ->
+             (* NOTE: We need to know whether an action was successful
+                or not to know which version of the opam file to store
+                in the case: the previous one if it failed, or the new
+                one if it succeeded. *)
+             let pkg_failed =
+               List.exists (function
+                   | `Fetch ps -> List.for_all (OpamPackage.equal nv) ps
+                   | `Build p | `Change (_, _, p) | `Install p
+                   | `Reinstall p | `Remove p -> OpamPackage.equal nv p)
+                 failed
+             in
+             let add_to_opams opam =
+               let opam = OpamFile.OPAM.with_metadata_dir None opam in
+               OpamPackage.Map.add nv opam opams
+             in
+             if pkg_failed then
+               match OpamPackage.Map.find_opt nv t.installed_opams with
+               | None -> opams
+               | Some opam -> add_to_opams opam
+             else
+               add_to_opams (OpamSwitchState.opam t nv))
+            t.installed OpamPackage.Map.empty);
   in
   begin match action_results with
   | `Exception _ | `Error Aborted -> ()
@@ -939,7 +940,10 @@ let parallel_apply t
       (* Cleanup build/install actions when one of them failed, it's verbose and
          doesn't add information *)
       let successful =
-        let was_successful p = not @@ List.mem (`Install p) failed in
+        let was_successful p =
+          not (OpamStd.List.mem (OpamTypesBase.action_equal OpamPackage.equal)
+                 (`Install p) failed)
+        in
         List.filter (function
             | `Fetch ps -> List.for_all was_successful ps
             | `Build p -> was_successful p
@@ -949,10 +953,12 @@ let parallel_apply t
       let remaining =
         List.filter (function
             | `Remove p | `Install p
-              when List.mem (`Build p) failed -> false
+              when
+                OpamStd.List.mem (OpamTypesBase.action_equal OpamPackage.equal)
+                  (`Build p) failed -> false
             | `Remove p | `Install p | `Build p
               when List.exists (function
-                  | `Fetch ps -> List.mem p ps
+                  | `Fetch ps -> OpamStd.List.mem OpamPackage.equal p ps
                   | _ -> false) failed
               -> false
             | `Build _ | `Change _ | `Fetch _ | `Install _
@@ -962,7 +968,10 @@ let parallel_apply t
       let removes_missing_source =
         List.filter (function
             | `Remove p as rem ->
-              let is_fetch = function `Fetch ps -> List.mem p ps | _ -> false in
+              let is_fetch = function
+                | `Fetch ps -> OpamStd.List.mem OpamPackage.equal p ps
+                | _ -> false
+              in
               List.exists is_fetch failed
               && PackageActionGraph.fold_edges (fun v v' mem ->
                   mem || (is_fetch v && PackageAction.equal v' rem))
@@ -977,8 +986,12 @@ let parallel_apply t
         List.filter (function
             | `Fetch _ as a ->
               let succ = PackageActionGraph.succ action_graph a in
-              not (List.for_all (fun a -> List.mem a removes_missing_source)
-                     succ)
+              not (
+                List.for_all (fun a ->
+                    OpamStd.List.mem
+                      (OpamTypesBase.action_equal OpamPackage.equal)
+                      a removes_missing_source)
+                  succ)
             | `Build _ | `Change _ | `Install _ | `Reinstall _
             | `Remove _ -> true)
           failed
@@ -987,7 +1000,10 @@ let parallel_apply t
         if l = [] then PackageActionGraph.create () else
         let g = PackageActionGraph.copy action_graph in
         PackageActionGraph.iter_vertex (fun v ->
-            if not (List.mem v l) then PackageActionGraph.remove_vertex g v)
+            if not (OpamStd.List.mem
+                      (OpamTypesBase.action_equal OpamPackage.equal)
+                      v l) then
+              PackageActionGraph.remove_vertex g v)
           g;
         g
       in
@@ -1078,14 +1094,15 @@ let dry_run state solution =
 (* Ask confirmation whenever the packages to modify are not exactly
    the packages in the user request *)
 let confirmation ?ask requested solution =
-  OpamCoreConfig.answer_is_yes () ||
+  OpamCoreConfig.answer_is_yes ~name:None () ||
   ask = Some false ||
   let solution_packages =
     OpamPackage.names_of_packages (OpamSolver.all_packages solution)
   in
   ask <> Some true && OpamPackage.Name.Set.equal requested solution_packages ||
   let stats = OpamSolver.stats solution in
-  OpamConsole.confirm "\nProceed with %s?" (OpamSolver.string_of_stats stats)
+  OpamConsole.confirm ~name:"proceed-actions" "\nProceed with %s?"
+    (OpamSolver.string_of_stats stats)
 
 let run_hook_job t name ?(local=[]) ?(allow_stdout=false) w =
   let shell_env = OpamEnv.get_full ~set_opamroot:true ~set_opamswitch:true ~force_path:true t in
@@ -1306,7 +1323,7 @@ let install_sys_packages_t ~propagate_st ~map_sysmap ~confirm env config
       "You can retry with '--assume-depexts' to skip this check, or run 'opam \
        option depext=false' to permanently disable handling of system \
        packages.\n%s"
-      (if OpamStd.Sys.tty_in || OpamCoreConfig.answer_is `unsafe_yes then ""
+      (if OpamStd.Sys.tty_in || OpamCoreConfig.answer_is ~name:None `unsafe_yes then ""
        else "Running the system package manager non-interactively requires \
              '--confirm-level=unsafe-yes'.\n")
   and give_up () =
@@ -1350,7 +1367,7 @@ let install_depexts ?(force_depext=false) ?(confirm=true) t
   in
   let env = t.switch_global.global_variables in
   let config = t.switch_global.config in
-  install_sys_packages_t ~propagate_st:OpamStd.Option.some ~map_sysmap ~confirm
+  install_sys_packages_t ~propagate_st:Stdlib.Option.some ~map_sysmap ~confirm
     env config sys_packages t
 
 let install_sys_packages ~confirm =
@@ -1414,7 +1431,7 @@ let apply ?ask t ~requested ?print_requested ?add_roots
       let messages p =
         let opam = OpamSwitchState.opam new_state p in
         let messages = OpamFile.OPAM.messages opam in
-        OpamStd.List.filter_map (fun (s,f) ->
+        List.filter_map (fun (s,f) ->
           if OpamFilter.opt_eval_to_bool
               (OpamPackageVar.resolve ~opam new_state) f
           then Some s
