@@ -348,7 +348,7 @@ let create
     in
     OpamStd.Exn.finalise e @@ fun () ->
     let gt, st =
-      if OpamConsole.confirm "Switch initialisation failed: clean up? \
+      if OpamConsole.confirm ~name:"switch-clean-up" "Switch initialisation failed: clean up? \
                               ('n' will leave the switch partially installed)"
       then clear_switch gt st.switch, st
       else if update_config && not simulate
@@ -399,8 +399,7 @@ let import_t ?ask ?(deps_only=false) importfile t =
   in
   OpamHash.Map.iter (fun hash content ->
       let value = Base64.decode_exn ~pad:false content in
-      let my = OpamHash.compute_from_string ~kind:(OpamHash.kind hash) value in
-      if OpamHash.contents my = OpamHash.contents hash then
+      if OpamHash.check_string value hash then
         let dst =
           let base = OpamFilename.Base.of_string (OpamHash.contents hash) in
           OpamFilename.create xfiles_dir base
@@ -528,7 +527,10 @@ let import_t ?ask ?(deps_only=false) importfile t =
             opam)
       pinned;
     (* Save new pinnings *)
-    let sel = OpamSwitchState.load_selections t.switch_global t.switch in
+    let sel =
+      OpamSwitchState.load_selections ~lock_kind:`Lock_write
+        t.switch_global t.switch
+    in
     S.write
       (OpamPath.Switch.selections t.switch_global.root t.switch)
       { sel with sel_pinned = pinned }
@@ -549,7 +551,7 @@ let freeze_url src_dir nv url =
         (OpamUrl.to_string url_t)
     | Some hash ->
       OpamFile.URL.with_url
-        { url_t with hash = Some (OpamPackage.Version.to_string hash) }
+        { url_t with hash = Some hash }
         url)
   | `http ->
     (match OpamFile.URL.checksum url with
@@ -566,7 +568,7 @@ let freeze_url src_dir nv url =
 
 let freeze_opam src_dir nv opam =
   let url =
-    OpamStd.Option.map
+    Stdlib.Option.map
       (fun url -> freeze_url src_dir nv url)
       (OpamFile.OPAM.url opam)
   in
@@ -625,18 +627,19 @@ let export rt ?(freeze=false) ?(full=false)
         opams OpamPackage.Name.Map.empty
     in
     let extra_files =
-      let repos_roots = OpamRepositoryState.get_root rt in
+      let get_repo_files = OpamRepositoryState.get_repo_files rt in
       OpamPackage.Map.fold (fun nv opam hmap ->
-          match OpamFile.OPAM.get_extra_files ~repos_roots opam with
+          match OpamFile.OPAM.get_extra_files ~get_repo_files opam with
           | [] -> hmap
           | files ->
             let hmap, err =
-              List.fold_left (fun (hmap,err) (file, base, hash) ->
-                  if OpamFilename.exists file &&
-                     OpamHash.check_file (OpamFilename.to_string file) hash then
-                    let value = Base64.encode_string ~pad:false (OpamFilename.read file) in
+              List.fold_left (fun (hmap,err) (base, content, hash) ->
+                  match content with
+                  | Some (lazy content) when
+                      OpamHash.check_string content hash ->
+                    let value = Base64.encode_string ~pad:false content in
                     OpamHash.Map.add hash value hmap, err
-                  else hmap, base::err)
+                  | None | Some _ -> hmap, base::err)
                 (hmap,[]) files
             in
             if err <> [] then
@@ -743,11 +746,17 @@ let guess_compiler_invariant ?repos rt strings =
   in
   let opams = OpamRepositoryState.build_index rt repos  in
   let packages = OpamPackage.keys opams in
-  let compiler_packages =
-    OpamPackage.Map.filter
-      (fun _ -> OpamFile.OPAM.has_flag Pkgflag_Compiler)
-      opams
-    |> OpamPackage.keys
+  let compiler_packages, removed_compiler_packages =
+    OpamPackage.Map.fold (fun nv opam (comp, avoid) ->
+        if OpamFile.OPAM.has_flag Pkgflag_Compiler opam then
+          if OpamFile.OPAM.has_flag Pkgflag_AvoidVersion opam
+          || OpamFile.OPAM.has_flag Pkgflag_Deprecated opam then
+            comp, OpamPackage.Set.add nv avoid
+          else
+            OpamPackage.Set.add nv comp, avoid
+        else
+          comp, avoid)
+      opams OpamPackage.Set.(empty, empty)
   in
   let invariant =
     List.fold_left (fun acc str ->
@@ -760,13 +769,27 @@ let guess_compiler_invariant ?repos rt strings =
         with Failure _ | Not_found ->
         try
           let v = OpamPackage.Version.of_string str in
+          let filter =
+            OpamPackage.Set.filter (fun nv ->
+                OpamPackage.Version.equal nv.version v)
+          in
           let candidates =
-            OpamPackage.Set.filter (fun nv -> nv.version = v)
-              compiler_packages
+            let candidates = filter compiler_packages in
+            if OpamPackage.Set.is_empty candidates then
+              let avoided_candidates = filter removed_compiler_packages in
+              if OpamPackage.Set.is_empty avoided_candidates then
+                raise Not_found
+              else
+                (if not (OpamPackage.Set.is_singleton avoided_candidates) then
+                   OpamConsole.note
+                     "Compilers found for version %s are all flagged with \
+                      'avoid-version'.\nIt is better to use a more explicit \
+                      command like \
+                      'opam switch create <switch-name> <package-name.version>'"
+                     str;
+                 avoided_candidates)
+            else candidates
           in
-          if OpamPackage.Set.is_empty candidates then
-            raise Not_found
-          else
           let disj =
             OpamPackage.Set.fold
               (fun nv acc ->
