@@ -11,10 +11,9 @@
 
 open OpamTypes
 open OpamStateTypes
-open OpamStd.Op
 
-type deps
-type revdeps
+type deps = private [`deps]
+type revdeps = private [`revdeps]
 type 'a node =
   | Root of package
   | Dependency : {
@@ -76,7 +75,7 @@ let build_condition_map tog st =
               (* filter out non-installed dependencies *)
               |> List.filter (fun (name, _) ->
                   OpamSwitchState.is_name_installed st name)
-              |> OpamStd.List.fold_left_map (fun is_valid orig ->
+              |> OpamCompat.List.fold_left_map (fun is_valid orig ->
                   if not is_valid then
                     is_valid, orig
                   else
@@ -165,7 +164,7 @@ let build_deps_forest st universe tog filter names =
     let conditions = condition_map |> OpamPackage.Map.find package in
     let succ = OpamSolver.PkgGraph.succ graph package in
     let visited, children =
-      OpamStd.List.fold_left_map (fun visited package ->
+      OpamCompat.List.fold_left_map (fun visited package ->
           let satisfies =
             OpamPackage.(Name.Map.find_opt package.name) conditions
           in
@@ -180,7 +179,7 @@ let build_deps_forest st universe tog filter names =
   in
   root
   |> OpamPackage.Set.elements
-  |> OpamStd.List.fold_left_map build_root OpamPackage.Set.empty
+  |> OpamCompat.List.fold_left_map build_root OpamPackage.Set.empty
   |> snd
 
 let build_revdeps_forest st universe tog filter names =
@@ -212,7 +211,7 @@ let build_revdeps_forest st universe tog filter names =
     let visited = visited |> OpamPackage.Set.add package in
     let pred = OpamSolver.PkgGraph.pred graph package in
     let visited, children =
-      OpamStd.List.fold_left_map (fun visited child ->
+      OpamCompat.List.fold_left_map (fun visited child ->
           let demands =
             condition_map
             |> OpamPackage.Map.find child
@@ -232,7 +231,7 @@ let build_revdeps_forest st universe tog filter names =
   in
   root
   |> OpamPackage.Set.elements
-  |> OpamStd.List.fold_left_map build_root OpamPackage.Set.empty
+  |> OpamCompat.List.fold_left_map build_root OpamPackage.Set.empty
   |> snd
 
 let build st universe tog mode filter names =
@@ -347,7 +346,7 @@ let print_solution st new_st missing solution =
   let messages p =
     let opam = OpamSwitchState.opam new_st p in
     let messages = OpamFile.OPAM.messages opam in
-    OpamStd.List.filter_map (fun (s,f) ->
+    List.filter_map (fun (s,f) ->
         if OpamFilter.opt_eval_to_bool
             (OpamPackageVar.resolve ~opam new_st) f
         then Some s
