@@ -20,6 +20,34 @@ module String = struct
       else loop (succ i) in
     loop 0
 
+  (** NOTE: OCaml >= 4.13 *)
+  let starts_with ~prefix s =
+    let x = String.length prefix in
+    let n = String.length s in
+    n >= x &&
+    let rec chk i = i >= x || prefix.[i] = s.[i] && chk (i+1) in
+    chk 0
+
+  (** NOTE: OCaml >= 4.13 *)
+  let ends_with ~suffix s =
+    let x = String.length suffix in
+    let n = String.length s in
+    n >= x &&
+    let rec chk i = i >= x || suffix.[i] = s.[i+n-x] && chk (i+1) in
+    chk 0
+
+  (** NOTE: OCaml >= 4.13 *)
+  let for_all f s =
+    let len = String.length s in
+    let rec aux i = i >= len || f s.[i] && aux (i+1) in
+    aux 0
+
+  (** NOTE: OCaml >= 4.13 *)
+  let fold_left f acc s =
+    let acc = ref acc in
+    for i = 0 to String.length s - 1 do acc := f !acc s.[i] done;
+    !acc
+
   include Stdlib.String
 end
 
@@ -73,6 +101,12 @@ module Lazy = struct
   let map f x =
     lazy (f (Lazy.force x))
 
+  (** NOTE: OCaml >= 4.13 *)
+  let map_val f x =
+    if Lazy.is_val x
+    then Lazy.from_val (f (Lazy.force x))
+    else lazy (f (Lazy.force x))
+
   include Stdlib.Lazy
 end
 
@@ -165,3 +199,55 @@ Quoting commands for execution by cmd.exe is difficult.
 
   include Stdlib.Filename
 end
+
+module List = struct
+  [@@@warning "-32"]
+
+  (** NOTE: OCaml >= 4.11 *)
+  let fold_left_map f s l =
+    let s, l_rev =
+      List.fold_left (fun (s, l_rev) x ->
+          let s, y = f s x in
+          s, y :: l_rev)
+        (s, []) l
+    in
+    s, List.rev l_rev
+
+  (* NOTE: OCaml >= 4.12 *)
+  let rec equal eq x y = match x, y with
+    | [], [] -> true
+    | [], _::_ | _::_, [] -> false
+    | x::_, y::_ when eq x y -> true
+    | _::xs, _::ys -> equal eq xs ys
+
+  include Stdlib.List
+end
+
+module type MAP = sig
+  include Stdlib.Map.S
+
+  (** NOTE: OCaml >= 4.11 *)
+  val filter_map: (key -> 'a -> 'b option) -> 'a t -> 'b t
+end
+
+module Map(Ord : Stdlib.Map.OrderedType) = struct
+  [@@@warning "-32"]
+
+  module M = Stdlib.Map.Make(Ord)
+
+  (** NOTE: OCaml >= 4.11 *)
+  let filter_map f map =
+    M.fold (fun key value map ->
+        match f key value with
+        | Some value -> M.add key value map
+        | None -> map
+      ) map M.empty
+
+  include M
+end
+
+module Pair = struct
+  (** NOTE: OCaml >= 5.4 *)
+  let equal eq1 eq2 (x1, y1) (x2, y2) =
+    eq1 x1 x2 && eq2 y1 y2
+end
