@@ -69,7 +69,7 @@ let utf8, utf8_extended =
           false
     else
       let checkv v =
-        try Some (OpamStd.String.ends_with ~suffix:"UTF-8" (OpamStd.Env.get v))
+        try Some (OpamCompat.String.ends_with ~suffix:"UTF-8" (OpamStd.Env.get v))
         with Not_found -> None
       in
       OpamStd.Option.Op.(checkv "LC_ALL" ++ checkv "LANG" +! false)
@@ -193,7 +193,7 @@ type text_style =
   [ `bold
   | `underline
   | `crossed
-  | `black
+  | `gray
   | `red
   | `green
   | `yellow
@@ -206,7 +206,7 @@ let style_code (c: text_style) = match c with
   | `bold      -> "01"
   | `underline -> "04"
   | `crossed   -> "09"
-  | `black     -> "30"
+  | `gray      -> "90"
   | `red       -> "31"
   | `green     -> "32"
   | `yellow    -> "33"
@@ -473,17 +473,6 @@ let rollback_terminal nlines =
     Printf.printf "\027[A"
   done
 
-let left_1_char =
-  let left_1_char_unix () = Printf.printf "\027[D%!" in
-  if Sys.win32 then
-    let f = lazy (
-      match get_win32_console_shim `stdout Mode with
-      | Shim -> fun () -> () (* unimplemented *)
-      | VT100 force -> fun () -> force (); left_1_char_unix ()
-    ) in
-    fun () -> Lazy.force f ()
-  else left_1_char_unix
-
 let displaying_status = ref false
 
 let clear_status_unix () =
@@ -573,7 +562,7 @@ let log section ?(level=1) fmt =
       | None -> debug_level
       | exception Not_found -> 0
   in
-  if not OpamCoreConfig.(!r.set) then
+  if not OpamCoreConfig.(!r.set) && OpamCoreConfig.(!r.in_opam) then
     let b = Buffer.create 128 in
     let timestamp = timestamp () ^ "  " in
     let k _ = Queue.push (level, timestamp, Buffer.contents b) pending in
@@ -725,17 +714,7 @@ let header_error fmt =
 (* Reads a single char from the user when possible, a line otherwise *)
 let short_user_input ~prompt ?default ?on_eof f =
   let on_eof = OpamStd.Option.Op.(on_eof ++ default) in
-  let prompt () = match default with
-    | Some x when OpamStd.Sys.tty_out ->
-      msg "%s%s" prompt x;
-      left_1_char ();
-      carriage_delete ();
-      (match List.rev (OpamStd.String.split prompt '\n') with
-       | lastline::_ -> print_string lastline
-       | [] -> ())
-    | _ ->
-      print_string prompt; flush stdout
-  in
+  let prompt () = print_string prompt; flush stdout in
   try
     if OpamStd.Sys.(not tty_out || os () = Win32 || os () = Cygwin) then
       let rec loop () =
@@ -769,9 +748,9 @@ let short_user_input ~prompt ?default ?on_eof f =
       match input with
       | None -> loop ()
       | Some i -> match f i with
-        | Some a ->
-          if String.length i > 0 && i.[0] <> '\027' then print_endline i;
-          a
+        | Some a when String.length i > 0 && i.[0] = '\027' ->
+          print_newline (); a
+        | Some a -> print_endline i; a
         | None -> loop ()
     in
     let attr = tcgetattr stdin in
@@ -801,25 +780,25 @@ let pause fmt =
         let prompt = OpamStd.Format.reformat s in
         short_user_input ~prompt ~default:""
         (function
-        | "\027" -> OpamStd.Sys.exit_because `Aborted
+        | "\027" -> print_newline (); OpamStd.Sys.exit_because `Aborted
         | _ -> Some ()))
       fmt
   else
     Printf.ifprintf () fmt
 
-let confirm ?(require_unsafe_yes=false) ?(default=true) fmt =
+let confirm ?(require_unsafe_yes=false) ?(default=true) ?name fmt =
   Printf.ksprintf (fun s ->
       if OpamCoreConfig.(!r.safe_mode) then false else
       let prompt =
         Printf.ksprintf OpamStd.Format.reformat "%s [%s/%s] " s
-          (colorise' (`blue :: if default then [`underline] else []) "y")
-          (colorise' (`blue :: if default then [] else [`underline]) "n")
+          (colorise `blue (if default then "Y" else "y"))
+          (colorise `blue (if default then "n" else "N"))
       in
-      if OpamCoreConfig.answer_is `unsafe_yes ||
-         not require_unsafe_yes && OpamCoreConfig.answer_is_yes ()
+      if OpamCoreConfig.answer_is ~name `unsafe_yes ||
+         not require_unsafe_yes && OpamCoreConfig.answer_is_yes ~name ()
       then
         (formatted_msg "%sy\n" prompt; true)
-      else if OpamCoreConfig.answer_is `all_no ||
+      else if OpamCoreConfig.answer_is ~name `all_no ||
               OpamStd.Sys.(not tty_in)
       then
         (formatted_msg "%sn\n" prompt; false)
@@ -835,7 +814,7 @@ let confirm ?(require_unsafe_yes=false) ?(default=true) fmt =
 let read fmt =
   Printf.ksprintf (fun s ->
       formatted_msg "%s " s;
-      if OpamCoreConfig.(answer_is `ask && not !r.safe_mode) then (
+      if OpamCoreConfig.(answer_is ~name:None `ask && not !r.safe_mode) then (
         try match read_line () with
           | "" -> None
           | s  -> Some s
@@ -1004,7 +983,7 @@ let menu ?default ?unsafe_yes ?yes ~no ~options fmt =
     let default_s = OpamStd.(List.assoc Compare.equal default options_nums) in
     let no_s = OpamStd.(List.assoc Compare.equal no options_nums) in
     if OpamCoreConfig.(!r.safe_mode) then no else
-    match OpamCoreConfig.answer(), unsafe_yes, yes with
+    match OpamCoreConfig.answer ~name:None (), unsafe_yes, yes with
     | `unsafe_yes, Some a, _ -> print_string prompt; select a
     | #OpamStd.Config.yes_answer, _, Some a -> print_string prompt; select a
     | `all_no, _, _ -> print_string prompt; select no
