@@ -46,7 +46,7 @@ module Dir = struct
     let dirname =
       if dirname = "~" then OpamStd.Sys.home ()
       else if
-        OpamStd.String.starts_with ~prefix:("~"^Filename.dir_sep) dirname
+        OpamCompat.String.starts_with ~prefix:("~"^Filename.dir_sep) dirname
       then
         Filename.concat (OpamStd.Sys.home ())
           (OpamStd.String.remove_prefix ~prefix:("~"^Filename.dir_sep) dirname)
@@ -159,6 +159,11 @@ let create dirname basename =
   if basename = b2 then
     { dirname; basename }
   else
+    let b1 =
+      if dirname = ""
+      then b1
+      else OpamStd.String.remove_prefix ~prefix:Filename.dir_sep b1
+    in
     { dirname = dirname / b1; basename = b2 }
 
 let of_basename basename =
@@ -336,10 +341,10 @@ let is_exec file =
     OpamSystem.internal_error "%s does not exist." (to_string file)
 
 let starts_with dirname filename =
-  OpamStd.String.starts_with ~prefix:(Dir.to_string dirname) (to_string filename)
+  OpamCompat.String.starts_with ~prefix:(Dir.to_string dirname) (to_string filename)
 
 let dir_starts_with pfx dir =
-  OpamStd.String.starts_with ~prefix:(Dir.to_string pfx) (Dir.to_string dir)
+  OpamCompat.String.starts_with ~prefix:(Dir.to_string pfx) (Dir.to_string dir)
 
 let remove_prefix prefix filename =
   let prefix =
@@ -406,10 +411,10 @@ let extract_generic_file filename dirname =
     )
 
 let ends_with suffix filename =
-  OpamStd.String.ends_with ~suffix (to_string filename)
+  OpamCompat.String.ends_with ~suffix (to_string filename)
 
 let dir_ends_with suffix dirname =
-  OpamStd.String.ends_with ~suffix (Dir.to_string dirname)
+  OpamCompat.String.ends_with ~suffix (Dir.to_string dirname)
 
 let remove_suffix suffix filename =
   let suffix = Base.to_string suffix in
@@ -443,9 +448,26 @@ let link ?(relative=false) ~target ~link =
   OpamSystem.link target (to_string link)
 [@@ocaml.warning "-16"]
 
-let patch ?preprocess ~allow_unclean filename dirname =
-  OpamSystem.patch ?preprocess ~allow_unclean ~dir:(Dir.to_string dirname)
-    (to_string filename)
+let parse_patch ~dir patch_file =
+  OpamSystem.parse_patch ~dir:(Dir.to_string dir) ~file:(to_string patch_file)
+
+let patch ~allow_unclean patch_source dir =
+  let operations_result diffs =
+    Ok (List.map (fun d -> d.Patch.operation) diffs)
+  in
+  let patch ?patch_filename diffs =
+    OpamSystem.patch ~allow_unclean ?patch_filename ~dir:(Dir.to_string dir)
+      diffs
+  in
+  try
+    match patch_source with
+    | `Patch_diffs diffs -> patch diffs;
+      operations_result diffs
+    | `Patch_file p ->
+      let diffs = parse_patch ~dir:(Dir.to_string dir) p in
+      patch ~patch_filename:(to_string p) diffs;
+      operations_result diffs
+  with exn -> Error exn
 
 let flock flag ?dontblock file = OpamSystem.flock flag ?dontblock (to_string file)
 
@@ -468,7 +490,7 @@ let with_flock flag ?dontblock file f =
     in
     let r = f fd in
     OpamSystem.funlock lock;
-    OpamStd.Option.iter Stdlib.close_out ch;
+    Option.iter Stdlib.close_out ch;
     r
   with e ->
     OpamStd.Exn.finalise e @@ fun () ->
@@ -503,7 +525,7 @@ let with_flock_write_then_read ?dontblock file write read =
 let prettify_path s =
   let aux ~short ~prefix =
     let prefix = Filename.concat prefix "" in
-    if OpamStd.String.starts_with ~prefix s then
+    if OpamCompat.String.starts_with ~prefix s then
       let suffix = OpamStd.String.remove_prefix ~prefix s in
       Some (Filename.concat short suffix)
     else
@@ -648,7 +670,7 @@ module Attribute = struct
     if base <> 0 then base else
     let md5 = OpamHash.compare md5 a.md5 in
     if md5 <> 0 then md5 else
-      OpamStd.Option.compare Int.compare perm a.perm
+      Option.compare Int.compare perm a.perm
 
   let equal a b = compare a b = 0
 
