@@ -1,6 +1,6 @@
 (**************************************************************************)
 (*                                                                        *)
-(*    Copyright 2012-2015 OCamlPro                                        *)
+(*    Copyright 2012-2019 OCamlPro                                        *)
 (*                                                                        *)
 (*  All rights reserved. This file is distributed under the terms of the  *)
 (*  GNU Lesser General Public License version 2.1, with the special       *)
@@ -17,8 +17,13 @@ type t =
   [ `Null | `Bool of bool | `Float of float| `String of string
   | `A of t list | `O of (string * t) list ]
 
-val to_string : t -> string
+type 'a encoder = 'a -> t
+type 'a decoder = t -> 'a option
 
 val append: string -> t -> unit
 
 val flush: out_channel -> unit
+
+val to_string : ?minify:bool -> t -> string
+
+val of_string: ?encoding:Jsonm.encoding -> string -> t option
