@@ -11,10 +11,8 @@
 
 module type SET = sig
   include Set.S
-  val map: (elt -> elt) -> t -> t
   val is_singleton: t -> bool
   val choose_one : t -> elt
-  val choose_opt : t -> elt option
   val of_list: elt list -> t
   val to_list_map: (elt -> 'b) -> t -> 'b list
   val to_string: t -> string
@@ -33,14 +31,12 @@ module type SET = sig
   end
 end
 module type MAP = sig
-  include Map.S
+  include OpamCompat.MAP
   val to_string: ('a -> string) -> 'a t -> string
   val to_json: 'a OpamJson.encoder -> 'a t OpamJson.encoder
   val of_json: 'a OpamJson.decoder -> 'a t OpamJson.decoder
   val keys: 'a t -> key list
   val values: 'a t -> 'a list
-  val find_opt: key -> 'a t -> 'a option
-  val choose_opt: 'a t -> (key * 'a) option
   val union: ('a -> 'a -> 'a) -> 'a t -> 'a t -> 'a t
   val is_singleton: 'a t -> bool
   val of_list: (key * 'a) list -> 'a t
@@ -48,7 +44,6 @@ module type MAP = sig
   val update: key -> ('a -> 'a) -> 'a -> 'a t -> 'a t
   val map_reduce:
     ?default:'b -> (key -> 'a -> 'b) -> ('b -> 'b -> 'b) -> 'a t -> 'b
-  val filter_map: (key -> 'a -> 'b option) -> 'a t -> 'b t
 end
 module type ABSTRACT = sig
   type t
@@ -84,8 +79,6 @@ let max_print = 100
 
 module OpamList = struct
 
-  let cons x xs = x :: xs
-
   let concat_map ?(left="") ?(right="") ?nil ?last_sep sep f =
     let last_sep = match last_sep with None -> sep | Some sep -> sep in
     function
@@ -118,10 +111,6 @@ module OpamList = struct
       assert (pos = 0);
       Bytes.to_string buf
 
-  let rec find_opt f = function
-    | [] -> None
-    | x::r -> if f x then Some x else find_opt f r
-
   let to_string f =
     concat_map ~left:"{ " ~right:" }" ~nil:"{}" ", " f
 
@@ -133,16 +122,7 @@ module OpamList = struct
   let sort_nodup cmp l =
     remove_duplicates (fun a b -> cmp a b = 0) (List.sort cmp l)
 
-  let filter_map f l =
-    let rec loop accu = function
-      | []     -> List.rev accu
-      | h :: t ->
-        match f h with
-        | None   -> loop accu t
-        | Some x -> loop (x::accu) t in
-    loop [] l
-
-  let filter_some l = filter_map (fun x -> x) l
+  let filter_some l = List.filter_map (fun x -> x) l
 
   let rec find_map f = function
     | [] -> raise Not_found
@@ -168,6 +148,10 @@ module OpamList = struct
     | l when index <= 0 -> value :: l
     | x::l -> x :: insert_at (index - 1) value l
 
+  let rec mem eq a = function
+    | [] -> false
+    | x::xs -> if eq a x then true else mem eq a xs
+
   let rec assoc eq x = function
     | [] -> raise Not_found
     | (a,b)::r -> if eq a x then b else assoc eq x r
@@ -216,15 +200,6 @@ module OpamList = struct
     in
     aux [] l
 
-  let fold_left_map f s l =
-    let s, l_rev =
-      List.fold_left (fun (s, l_rev) x ->
-          let s, y = f s x in
-          s, y :: l_rev)
-        (s, []) l
-    in
-    s, List.rev l_rev
-
 end
 
 
@@ -236,13 +211,6 @@ module Set = struct
 
     include S
 
-    let fold f set i =
-      let r = ref i in
-      S.iter (fun elt ->
-          r := f elt !r
-        ) set;
-      !r
-
     let is_singleton s =
       not (is_empty s) &&
       min_elt s == max_elt s
@@ -252,9 +220,6 @@ module Set = struct
       else if is_singleton s then choose s
       else failwith "choose_one"
 
-    let choose_opt s =
-      try Some (choose s) with Not_found -> None
-
     let of_list l =
       List.fold_left (fun set e -> add e set) empty l
 
@@ -268,9 +233,6 @@ module Set = struct
         let l = S.fold (fun nv l -> O.to_string nv :: l) s [] in
         OpamList.to_string (fun x -> x) (List.rev l)
 
-    let map f t =
-      S.fold (fun e set -> S.add (f e) set) t S.empty
-
     exception Found of elt
 
     let find_opt fn t =
@@ -337,34 +299,10 @@ module Map = struct
 
   module Make (O : OrderedType) = struct
 
-    module M = Map.Make(O)
+    module M = OpamCompat.Map(O)
 
     include M
 
-    let fold f map i =
-      let r = ref i in
-      M.iter (fun key value->
-          r:= f key value !r
-        ) map;
-      !r
-
-    let map f map =
-      fold (fun key value map ->
-          add key (f value) map
-        ) map empty
-
-    let mapi f map =
-      fold (fun key value map ->
-          add key (f key value) map
-        ) map empty
-
-    let filter_map f map =
-      fold (fun key value map ->
-          match f key value with
-          | Some value -> add key value map
-          | None -> map
-        ) map empty
-
     let values map =
       List.rev (M.fold (fun _ v acc -> v :: acc) map [])
 
@@ -420,11 +358,6 @@ module Map = struct
         end
       | _ -> None
 
-    let find_opt k map = try Some (find k map) with Not_found -> None
-
-    let choose_opt m =
-      try Some (choose m) with Not_found -> None
-
     let safe_add k v map =
       if mem k map
       then failwith (Printf.sprintf "duplicate entry %s" (O.to_string k))
@@ -484,14 +417,6 @@ module IntSet = Set.Make(OInt)
 
 
 module Option = struct
-  let map f = function
-    | None -> None
-    | Some x -> Some (f x)
-
-  let iter f = function
-    | None -> ()
-    | Some x -> f x
-
   let default dft = function
     | None -> dft
     | Some x -> x
@@ -508,28 +433,14 @@ module Option = struct
     | None -> dft
     | Some x -> f x
 
-  let compare cmp o1 o2 =
-    match o1,o2 with
-    | None, None -> 0
-    | Some _, None -> 1
-    | None, Some _ -> -1
-    | Some x1, Some x2 -> cmp x1 x2
-
-  let equal f o1 o2 =
-    match o1, o2 with
-    | Some o1, Some o2 -> f o1 o2
-    | None, None -> true
-    | _ , _  -> false
+  let equal_some f v1 = function
+    | None -> false
+    | Some v2 -> f v1 v2
 
   let to_string ?(none="") f = function
     | Some x -> f x
     | None -> none
 
-  let to_list = function
-    | None -> []
-    | Some x -> [x]
-
-  let some x = Some x
   let none _ = None
 
   let of_Not_found f x =
@@ -539,7 +450,7 @@ module Option = struct
     let (>>=) = function
       | None -> fun _ -> None
       | Some x -> fun f -> f x
-    let (>>|) opt f = map f opt
+    let (>>|) opt f = Option.map f opt
     let (>>+) opt f = match opt with
       | None -> f ()
       | some -> some
@@ -550,7 +461,15 @@ module Option = struct
   end
 end
 
+module OpamChar = struct
 
+  (* TODO: Replace by Stdlib.Char.Ascii.is_space
+     (to be introduced in OCaml 5.4) *)
+  let is_whitespace = function
+    | ' ' | '\t' | '\r' | '\n' -> true
+    | _ -> false
+
+end
 
 module OpamString = struct
 
@@ -573,29 +492,6 @@ module OpamString = struct
   module Set = StringSet
   module Map = StringMap
 
-  let starts_with ~prefix s =
-    let x = String.length prefix in
-    let n = String.length s in
-    n >= x &&
-    let rec chk i = i >= x || prefix.[i] = s.[i] && chk (i+1) in
-    chk 0
-
-  let ends_with ~suffix s =
-    let x = String.length suffix in
-    let n = String.length s in
-    n >= x &&
-    let rec chk i = i >= x || suffix.[i] = s.[i+n-x] && chk (i+1) in
-    chk 0
-
-  let for_all f s =
-    let len = String.length s in
-    let rec aux i = i >= len || f s.[i] && aux (i+1) in
-    aux 0
-
-  let contains_char s c =
-    try let _ = String.index s c in true
-    with Not_found -> false
-
   let contains ~sub =
     Re.(execp (compile (str sub)))
 
@@ -624,32 +520,22 @@ module OpamString = struct
           raise Not_found in
       g i
 
-  let map f s =
-    let len = String.length s in
-    let b = Bytes.create len in
-    for i = 0 to len - 1 do Bytes.set b i (f s.[i]) done;
-    Bytes.to_string b
-
-  let is_whitespace = function
-    | ' ' | '\t' | '\r' | '\n' -> true
-    | _ -> false
-
   let strip str =
     let p = ref 0 in
     let l = String.length str in
-    while !p < l && is_whitespace (String.unsafe_get str !p) do
+    while !p < l && OpamChar.is_whitespace (String.unsafe_get str !p) do
       incr p;
     done;
     let p = !p in
     let l = ref (l - 1) in
-    while !l >= p && is_whitespace (String.unsafe_get str !l) do
+    while !l >= p && OpamChar.is_whitespace (String.unsafe_get str !l) do
       decr l;
     done;
     String.sub str p (!l - p + 1)
 
   let strip_right str =
     let rec aux i =
-      if i < 0 || not (is_whitespace str.[i]) then i else aux (i-1)
+      if i < 0 || not (OpamChar.is_whitespace str.[i]) then i else aux (i-1)
     in
     let l = String.length str in
     let i = aux (l-1) in
@@ -663,7 +549,7 @@ module OpamString = struct
       String.sub s 0 n
 
   let remove_prefix ~prefix s =
-    if starts_with ~prefix s then
+    if OpamCompat.String.starts_with ~prefix s then
       let x = String.length prefix in
       let n = String.length s in
       String.sub s x (n - x)
@@ -671,7 +557,7 @@ module OpamString = struct
       s
 
   let remove_suffix ~suffix s =
-    if ends_with ~suffix s then
+    if OpamCompat.String.ends_with ~suffix s then
       let x = String.length suffix in
       let n = String.length s in
       String.sub s 0 (n - x)
@@ -692,9 +578,25 @@ module OpamString = struct
   let rcut_at = cut_at_aux String.rindex
 
   let split s c =
-    (* old compat version (Re 1.2.0)
-       {[Re_str.split (Re_str.regexp (Printf.sprintf "[%c]+" c)) s]} *)
-    Re.(split (compile (rep1 (char c)))) s
+    let rec loop acc i slice_start len s c =
+      if (i : int) < (len : int) then
+        if s.[i] = (c : char) then
+          let acc =
+            if (slice_start : int) < (i : int) then
+              String.sub s slice_start (i - slice_start) :: acc
+            else
+              acc
+          in
+          let i = i+1 in
+          loop acc i i len s c
+        else
+          loop acc (i+1) slice_start len s c
+      else if (i : int) = (slice_start : int) then
+        acc
+      else
+        String.sub s slice_start (len - slice_start) :: acc
+    in
+    List.rev (loop [] 0 0 (String.length s) s c)
 
   let split_delim s c =
     let tokens = Re.(split_full (compile (char c)) s) in
@@ -730,11 +632,6 @@ module OpamString = struct
         f acc next current last normal in
     f [] 0 "" 0 true
 
-  let fold_left f acc s =
-    let acc = ref acc in
-    for i = 0 to String.length s - 1 do acc := f !acc s.[i] done;
-    !acc
-
   let compare_case s1 s2 =
     let l1 = String.length s1 and l2 = String.length s2 in
     let len = min l1 l2 in
@@ -785,7 +682,7 @@ module Env = struct
   (* Remove from a c-separated list of string the one with the given prefix *)
   let reset_value ~prefix c v =
     let v = OpamString.split v c in
-    List.filter (fun v -> not (OpamString.starts_with ~prefix v)) v
+    List.filter (fun v -> not (OpamCompat.String.starts_with ~prefix v)) v
 
   (* Split the list in two according to the first occurrence of the string
      starting with the given prefix.
@@ -795,7 +692,7 @@ module Env = struct
     let rec aux before =
       function
       | [] -> [], List.rev before
-      | curr::after when OpamString.starts_with ~prefix curr ->
+      | curr::after when OpamCompat.String.starts_with ~prefix curr ->
         before, after
       | curr::after -> aux (curr::before) after
     in aux [] v
@@ -991,20 +888,17 @@ module OpamSys = struct
 
   let etc () = "/etc"
 
-  let memo_command =
-    let memo = Hashtbl.create 7 in
-    fun cmd arg ->
-      try Hashtbl.find memo (cmd, arg) with Not_found ->
-        let r =
-          match process_in cmd [arg] with
-          | None -> None
-          | Some x -> Some (OpamString.strip x)
-        in
-        Hashtbl.add memo (cmd, arg) r;
-        r
+  let uname =
+    let uname = lazy (OpamStubs.uname ()) in
+    fun () ->
+      Lazy.force uname
 
-  let uname = memo_command "uname"
-  let getconf = memo_command "getconf"
+  (* We need to call [uname] here as the only way to get it
+     in C without calling a process or lookup files is to
+     use [__Freebsd_version] which is a define, so it is set
+     at compile time. *)
+  let get_freebsd_version () = process_in "uname" ["-U"]
+  let get_long_bit () = process_in "getconf" ["LONG_BIT"]
 
   let system =
     let system = Lazy.from_fun OpamStubs.getPathToSystem in
@@ -1026,14 +920,14 @@ module OpamSys = struct
     let os = lazy (
       match Sys.os_type with
       | "Unix" -> begin
-          match uname "-s" with
-          | Some "Darwin"    -> Darwin
-          | Some "Linux"     -> Linux
-          | Some "FreeBSD"   -> FreeBSD
-          | Some "OpenBSD"   -> OpenBSD
-          | Some "NetBSD"    -> NetBSD
-          | Some "DragonFly" -> DragonFly
-          | _                -> Unix
+          match (uname ()).sysname with
+          | "Darwin"    -> Darwin
+          | "Linux"     -> Linux
+          | "FreeBSD"   -> FreeBSD
+          | "OpenBSD"   -> OpenBSD
+          | "NetBSD"    -> NetBSD
+          | "DragonFly" -> DragonFly
+          | _           -> Unix
         end
       | "Win32"  -> Win32
       | "Cygwin" -> Cygwin
@@ -1095,13 +989,13 @@ module OpamSys = struct
       | "cmd.exe" -> Some (Accept SH_cmd)
       | "" -> None
       | name ->
-        Option.map
+        Stdlib.Option.map
           (fun shell -> Accept shell)
           (shell_of_string (chop_exe_suffix name))
     in
     lazy (
       let lazy ancestors = windows_process_ancestry in
-      match OpamList.filter_map categorize_process ancestors with
+      match List.filter_map categorize_process ancestors with
       | [] -> None
       | Accept most_relevant_shell :: _ -> Some most_relevant_shell
     )
@@ -1155,6 +1049,28 @@ module OpamSys = struct
       in
       Option.default unix_default_shell shell
 
+  let guess_bash_dot_profile () =
+    let home f =
+      try Filename.concat (home ()) f
+      with Not_found -> f
+    in
+    try
+      List.find Sys.file_exists [
+        (* Bash looks up these 3 files in order and only loads the first,
+           for LOGIN shells *)
+        home ".bash_profile";
+        home ".bash_login";
+        home ".profile";
+        (* Bash loads .bashrc INSTEAD, for interactive NON login shells only;
+           but it's often included from the above.
+           We may include our variables in both to be sure ; for now we rely
+           on non-login shells inheriting their env from a login shell
+           somewhere... *)
+      ]
+    with Not_found ->
+      (* iff none of the above exist, creating this should be safe *)
+      home ".bash_profile"
+
   let guess_dot_profile shell =
     let home f =
       try Filename.concat (home ()) f
@@ -1162,27 +1078,13 @@ module OpamSys = struct
     match shell with
     | SH_fish ->
       Some (List.fold_left Filename.concat (home ".config") ["fish"; "config.fish"])
-    | SH_zsh  -> Some (home ".zshrc")
+    | SH_zsh  ->
+      let zsh_home f =
+        try Filename.concat (Env.get "ZDOTDIR") f
+        with Not_found -> home f in
+      Some (zsh_home ".zshrc")
     | SH_bash ->
-      let shell =
-        (try
-           List.find Sys.file_exists [
-             (* Bash looks up these 3 files in order and only loads the first,
-                for LOGIN shells *)
-             home ".bash_profile";
-             home ".bash_login";
-             home ".profile";
-             (* Bash loads .bashrc INSTEAD, for interactive NON login shells only;
-                but it's often included from the above.
-                We may include our variables in both to be sure ; for now we rely
-                on non-login shells inheriting their env from a login shell
-                somewhere... *)
-           ]
-         with Not_found ->
-           (* iff none of the above exist, creating this should be safe *)
-           home ".bash_profile")
-      in
-      Some shell
+      Some (home ".bashrc")
     | SH_csh ->
       let cshrc = home ".cshrc" in
       let tcshrc = home ".tcshrc" in
@@ -1211,7 +1113,7 @@ module OpamSys = struct
     let rec aux i =
       if (i : int) >= len then "" else
       let s = env.(i) in
-      if OpamString.starts_with ~prefix (f s) then
+      if OpamCompat.String.starts_with ~prefix (f s) then
         String.sub s pfxlen (String.length s - pfxlen)
       else aux (i+1)
     in
@@ -1225,7 +1127,7 @@ module OpamSys = struct
         fun x -> x
     in
     let name = forward_to_back name in
-    OpamString.contains_char name Filename.dir_sep.[0]
+    String.contains name Filename.dir_sep.[0]
 
   let resolve_in_path_t env name =
     if not (Filename.is_relative name) || is_external_cmd name then
@@ -1303,15 +1205,15 @@ module OpamSys = struct
           | dll ->
             (* Guard against any risk of stray \r characters *)
             let tdll = String.trim dll in
-            if OpamString.ends_with ~suffix:"cygwin1.dll" tdll then
-              if OpamString.starts_with ~prefix:"  " dll then
+            if OpamCompat.String.ends_with ~suffix:"cygwin1.dll" tdll then
+              if OpamCompat.String.starts_with ~prefix:"  " dll then
                 check_dll `Cygwin
               else if platform = `Native then
                 check_dll (`Tainted `Cygwin)
               else
                 check_dll platform
-            else if OpamString.ends_with ~suffix:"msys-2.0.dll" tdll then
-              if OpamString.starts_with ~prefix:"  " dll then
+            else if OpamCompat.String.ends_with ~suffix:"msys-2.0.dll" tdll then
+              if OpamCompat.String.starts_with ~prefix:"  " dll then
                 check_dll `Msys2
               else if platform = `Native then
                 check_dll (`Tainted `Msys2)
@@ -1734,10 +1636,6 @@ end
 
 module Op = struct
 
-  let (@@) f x = f x
-
-  let (|>) x f = f x
-
   let (@*) g f x = g (f x)
 
   let (@>) f g x = g (f x)
@@ -1770,7 +1668,7 @@ module Config = struct
   type yes_answer = [ `unsafe_yes | `all_yes ]
 
   let env conv var =
-    try Option.map conv (Env.getopt ("OPAM"^var))
+    try Stdlib.Option.map conv (Env.getopt ("OPAM"^var))
     with Failure _ ->
       flush stdout;
       !console.warning
@@ -1862,6 +1760,17 @@ module Config = struct
         try if bool s then `all_yes else `all_no
         with Failure _ -> answer s)
 
+  let auto_answer =
+    env (fun s ->
+        List.filter_map (fun s ->
+            match OpamString.cut_at s '=' with
+            | Some (k, x) ->
+              (match answer x with
+               | x -> Some (k, x)
+               | exception Failure _ -> None)
+            | None -> None)
+        (String.split_on_char ':' s))
+
 
   module E = struct
     type t = ..
@@ -1881,6 +1790,7 @@ module Config = struct
 end
 
 module List = OpamList
+module Char = OpamChar
 module String = OpamString
 module Sys = OpamSys
 module Format = OpamFormat
