@@ -18,8 +18,6 @@ module type SET = sig
 
   include Set.S
 
-  val map: (elt -> elt) -> t -> t
-
   val is_singleton: t -> bool
 
   (** Returns one element, assuming the set is a singleton.
@@ -27,8 +25,6 @@ module type SET = sig
       @raise Failure on a non-singleton *)
   val choose_one : t -> elt
 
-  val choose_opt: t -> elt option
-
   val of_list: elt list -> t
   val to_list_map: (elt -> 'b) -> t -> 'b list
   val to_string: t -> string
@@ -62,15 +58,13 @@ end
 (** Maps with extended interface *)
 module type MAP = sig
 
-  include Map.S
+  include OpamCompat.MAP
 
   val to_string: ('a -> string) -> 'a t  -> string
   val to_json: 'a OpamJson.encoder -> 'a t OpamJson.encoder
   val of_json: 'a OpamJson.decoder -> 'a t OpamJson.decoder
   val keys: 'a t -> key list
   val values: 'a t -> 'a list
-  val find_opt: key -> 'a t -> 'a option
-  val choose_opt: 'a t -> (key * 'a) option
 
   (** A key will be in the union of [m1] and [m2] if it is appears
       either [m1] or [m2], with the corresponding value. If a key
@@ -94,8 +88,6 @@ module type MAP = sig
       @raise Invalid_argument on an empty map if [default] is not defined *)
   val map_reduce:
     ?default:'b -> (key -> 'a -> 'b) -> ('b -> 'b -> 'b) -> 'a t -> 'b
-
-  val filter_map: (key -> 'a -> 'b option) -> 'a t -> 'b t
 end
 
 (** A signature for handling abstract keys and collections thereof *)
@@ -147,10 +139,6 @@ module IntSet: SET with type elt = int
 (** {2 Utility modules extending the standard library on base types} *)
 
 module Option: sig
-  val map: ('a -> 'b) -> 'a option -> 'b option
-
-  val iter: ('a -> unit) -> 'a option -> unit
-
   val default: 'a -> 'a option -> 'a
 
   val default_map: 'a option -> 'a option -> 'a option
@@ -159,18 +147,10 @@ module Option: sig
 
   val map_default: ('a -> 'b) -> 'b -> 'a option -> 'b
 
-  val compare: ('a -> 'a -> int) -> 'a option -> 'a option -> int
-
-  val equal: ('a -> 'a -> bool) -> 'a option -> 'a option -> bool
-
   val equal_some : ('a -> 'a -> bool) -> 'a -> 'a option -> bool
 
   val to_string: ?none:string -> ('a -> string) -> 'a option -> string
 
-  val to_list: 'a option -> 'a list
-
-  val some: 'a -> 'a option
-
   val none: 'a -> 'b option
 
   (** [of_Not_found f x] calls [f x], catches [Not_found] and returns [None] *)
@@ -187,17 +167,12 @@ end
 
 module List : sig
 
-  val cons: 'a -> 'a list -> 'a list
-
   (** Convert list items to string and concat. [concat_map sep f x] is equivalent
       to [String.concat sep (List.map f x)] but tail-rec. *)
   val concat_map:
     ?left:string -> ?right:string -> ?nil:string -> ?last_sep:string ->
     string -> ('a -> string) -> 'a list -> string
 
-  (** Like {!Stdlib.List.find}, but returning option instead of raising *)
-  val find_opt: ('a -> bool) -> 'a list -> 'a option
-
   val to_string: ('a -> string) -> 'a list -> string
 
   (** Removes consecutive duplicates in a list *)
@@ -206,9 +181,6 @@ module List : sig
   (** Sorts the list, removing duplicates *)
   val sort_nodup: ('a -> 'a -> int) -> 'a list -> 'a list
 
-  (** Filter and map *)
-  val filter_map: ('a -> 'b option) -> 'a list -> 'b list
-
   (** Retrieves [Some] values from a list *)
   val filter_some: 'a option list -> 'a list
 
@@ -228,6 +200,9 @@ module List : sig
       end if index < 0 or > length respectively). Not tail-recursive *)
   val insert_at: int -> 'a -> 'a list -> 'a list
 
+  (** Like {!List.mem} with an equality function. *)
+  val mem: ('a -> 'a -> bool) -> 'a -> 'a list -> bool
+
   (** Like {!List.assoc} with an equality function. *)
   val assoc: ('a -> 'a -> bool) -> 'a -> ('a * 'b) list -> 'b
 
@@ -256,10 +231,12 @@ module List : sig
 
   (** Like {!pick_assoc}, but with a test function that takes a list element *)
   val pick: ('a -> bool) -> 'a list -> 'a option * 'a list
+end
+
+module Char : sig
+
+  val is_whitespace : char -> bool
 
-  (** Like {!Stdlib.List.fold_left}, but also performs {!Stdlib.List.map} at
-      the same time *)
-  val fold_left_map: ('s -> 'a -> ('s * 'b)) -> 's -> 'a list -> 's * 'b list
 end
 
 module String : sig
@@ -278,10 +255,6 @@ module String : sig
 
   (** {3 Checks} *)
 
-  val starts_with: prefix:string -> string -> bool
-  val ends_with: suffix:string -> string -> bool
-  val for_all: (char -> bool) -> string -> bool
-  val contains_char: string -> char -> bool
   val contains: sub:string -> string -> bool
   val exact_match: Re.re -> string -> bool
   val find_from: (char -> bool) -> string -> int -> int
@@ -292,7 +265,6 @@ module String : sig
 
   (** {3 Manipulation} *)
 
-  val map: (char -> char) -> string -> string
   val strip: string -> string
   val strip_right: string -> string
   val sub_at: int -> string -> string
@@ -325,8 +297,6 @@ module String : sig
       [split_quoted "foo\";\"bar;baz" ';' = ["foo;bar"; "baz"]] *)
   val split_quoted: string -> char -> string list
 
-  val fold_left: ('a -> char -> 'a) -> 'a -> string -> 'a
-
   val is_hex: string -> bool
 
 end
@@ -546,6 +516,9 @@ module Sys : sig
       support the concept of a .profile file. *)
   val guess_dot_profile: shell -> string option
 
+  (** Guess the location of the .profile file for bash. *)
+  val guess_bash_dot_profile : unit -> string
+
   (** The separator character used in the PATH variable (varies depending on
       OS) *)
   val path_sep: char
@@ -667,12 +640,6 @@ end
 
 module Op: sig
 
-  (** Function application (with lower priority) (predefined in OCaml 4.01+) *)
-  val (@@): ('a -> 'b) -> 'a -> 'b
-
-  (** Pipe operator -- reverse application (predefined in OCaml 4.01+) *)
-  val (|>): 'a -> ('a -> 'b) -> 'b
-
   (** Function composition : (f @* g) x =~ f (g x) *)
   val (@*): ('b -> 'c) -> ('a -> 'b) -> 'a -> 'c
 
@@ -722,6 +689,8 @@ module Config : sig
 
   val env_answer: env_var -> answer option
 
+  val auto_answer: env_var -> (string * answer) list option
+
   module type Sig = sig
 
     (** Read-only record type containing the lib's configuration options *)
