@@ -20,7 +20,7 @@ val getpid : unit -> int
       faked process ID returned by the Microsoft C Runtime
       (see https://caml.inria.fr/mantis/view.php?id=4034).
 
-      On all other platforms, this is just an alias for [Unix.getpid]. *)
+      On all other platforms, this is just an alias for {!Unix.getpid}. *)
 
 val getCurrentProcessID : unit -> int32
   (** Windows only. As {!getpid}, but without the possibility of truncating the
@@ -113,7 +113,7 @@ val getProcessArchitecture : int32 option -> windows_cpu_architecture
 
 val process_putenv : int32 -> string -> string -> bool
 (** Windows only. [process_putenv pid name value] sets the environment variable
-    [name] to [value] in given process ID ([Unix.putenv] must also be called to
+    [name] to [value] in given process ID ({!Unix.putenv} must also be called to
     update the value in the current process). This function must not be called
     if the target process is 32-bit and the current process is 64-bit or vice
     versa (outcomes vary from a no-op to a segfault). *)
@@ -171,3 +171,14 @@ val get_stdout_ws_col : unit -> int
     linked with stdout. If stdout isn't linked to any terminal
     (e.g. redirection), then this function will return 0. A valid number
     of columns should be strictly above 0. *)
+
+type uname = {
+  sysname : string; (** uname -s *)
+  release : string; (** uname -r *)
+  machine : string; (** uname -m *)
+}
+(** A subset of the [struct utsname] C structure, as modified by uname(2),
+    converted to OCaml datatypes. *)
+
+val uname : unit -> uname
+(** Unix only. Returns info from uname(2) *)
