@@ -81,10 +81,18 @@ let real_path p =
 let temp_basename prefix =
   Printf.sprintf "%s-%d-%06x" prefix (OpamStubs.getpid ()) (Random.int 0xFFFFFF)
 
-let rec mk_temp_dir ?(prefix="opam") () =
-  let s = Filename.get_temp_dir_name () / temp_basename prefix in
+let temp_name ?dir ?(prefix="opam") () =
+  let tmpdir =
+    match dir with
+    | Some d -> d
+    | None -> Filename.get_temp_dir_name ()
+  in
+  tmpdir / (temp_basename prefix)
+
+let rec mk_temp_dir ?prefix () =
+  let s = temp_name ?prefix () in
   if Sys.file_exists s then
-    mk_temp_dir ~prefix ()
+    mk_temp_dir ?prefix ()
   else
     real_path s
 
@@ -110,11 +118,12 @@ let mkdir dir =
     end in
   aux dir
 
-let get_files dirname =
+let get_files_t ~except_vcs dirname =
   let dir = Unix.opendir dirname in
   let rec aux files =
     match Unix.readdir dir with
     | "." | ".." -> aux files
+    | ".git" | ".hg" | "_darcs" when except_vcs -> aux files
     | file -> aux (file :: files)
     | exception End_of_file -> files
   in
@@ -122,8 +131,11 @@ let get_files dirname =
   Unix.closedir dir;
   files
 
-let log_for_file_management () =
-  OpamCoreConfig.(!r.debug_level) >= 4
+let get_files = get_files_t ~except_vcs:false
+let get_files_except_vcs = get_files_t ~except_vcs:true
+
+let log_for_file_management with_log =
+  if with_log then 1 else 4
 
 (* From stdune/src/fpath.ml *)
 let win32_unlink fn =
@@ -137,8 +149,7 @@ let win32_unlink fn =
 
 let remove_file_t ?(with_log=true) file =
   try
-    if with_log || log_for_file_management () then
-      log "rm %s" file;
+    log ~level:(log_for_file_management with_log) "rm %s" file;
     if Sys.win32 then
       win32_unlink file
     else
@@ -146,18 +157,24 @@ let remove_file_t ?(with_log=true) file =
   with Unix.Unix_error _ as e ->
     internal_error "Cannot remove %s (%s)." file (Printexc.to_string e)
 
+let is_reg_dir dir =
+  match Unix.lstat dir with
+  | {Unix.st_kind = Unix.S_DIR; _} -> true
+  | {Unix.st_kind =
+       Unix.(S_REG | S_LNK | S_CHR | S_BLK | S_FIFO | S_SOCK); _} ->
+    false
+  | exception Unix.(Unix_error (ENOENT, _, _)) when Sys.win32 ->
+    (* This is usually caused by invalid symlinks extracted by a
+       Cygwin/MSYS2 tar. *)
+    false
+
 let rec remove_dir_t dir =
   let files = get_files dir in
   List.iter (fun file ->
       let file = Filename.concat dir file in
-      match Unix.lstat file with
-      | {Unix.st_kind = Unix.S_DIR; _} ->
+      if is_reg_dir file then
         remove_dir_t file
-      | {Unix.st_kind = Unix.(S_REG | S_LNK | S_CHR | S_BLK | S_FIFO | S_SOCK); _} ->
-        remove_file_t ~with_log:false file
-      | exception Unix.(Unix_error (ENOENT, _, _)) when Sys.win32 ->
-        (* This is usually caused by invalid symlinks extracted by a
-           Cygwin/MSYS2 tar. *)
+      else
         remove_file_t ~with_log:false file
     ) files;
   Unix.rmdir dir
@@ -165,7 +182,7 @@ let rec remove_dir_t dir =
 let remove_dir dir =
   log "rmdir %s" dir;
   if Sys.file_exists dir then begin
-    if Sys.is_directory dir then
+    if is_reg_dir dir then
       remove_dir_t dir
     else
       remove_file_t ~with_log:true dir
@@ -197,7 +214,7 @@ let rec temp_file ?(auto_clean=true) ?dir prefix =
     | None   -> OpamCoreConfig.(!r.log_dir)
     | Some d -> d in
   mkdir temp_dir;
-  let file = temp_dir / temp_basename prefix in
+  let file = temp_name ~dir:temp_dir ~prefix () in
   if Hashtbl.mem temp_files file then
     temp_file ~auto_clean ?dir prefix
   else (
@@ -237,6 +254,7 @@ let string_of_channel ic =
   Buffer.contents b
 
 let read file =
+  log ~level:5 "read %s" file;
   let ic =
     try open_in_bin file
     with Sys_error _ -> raise (File_not_found file) in
@@ -247,6 +265,7 @@ let read file =
 
 let write file contents =
   mkdir (Filename.dirname file);
+  log ~level:5 "write %s" file;
   let oc =
     try open_out_bin file
     with Sys_error _ -> raise (File_not_found file)
@@ -375,8 +394,25 @@ let dirs dir =
   directories_with_links dir
 
 let dir_is_empty dir =
-  try in_dir dir (fun () -> Sys.readdir (Sys.getcwd ()) = [||])
-  with File_not_found _ -> false
+  try
+    let dir = Unix.opendir dir in
+    Fun.protect ~finally:(fun () -> Unix.closedir dir) @@ fun () ->
+    let rec loop () =
+      match Unix.readdir dir with
+      | "." | ".." -> loop ()
+      | _ -> false
+      | exception End_of_file -> true
+    in
+    Some (loop ())
+  with Unix.Unix_error(Unix.ENOENT, _, _) -> None
+
+let rec rmdir_cleanup dirname =
+  if dir_is_empty dirname = Some true then (
+    remove_dir dirname;
+    let parent = Filename.dirname dirname in
+    if parent <> (dirname : string) then
+      rmdir_cleanup parent
+  )
 
 let with_tmp_dir fn =
   let dir = mk_temp_dir () in
@@ -398,6 +434,26 @@ let with_tmp_dir_job fjob =
   mkdir dir;
   OpamProcess.Job.finally (fun () -> remove_dir dir) (fun () -> fjob dir)
 
+let rec with_tmp_file fn =
+  let file = temp_name () in
+  if Sys.file_exists file then
+    with_tmp_file fn
+  else
+    try
+      let e = fn file in
+      remove_file file;
+      e
+    with e ->
+      OpamStd.Exn.finalise e @@ fun () ->
+      remove_file file
+
+let rec with_tmp_file_job fjob =
+  let file = temp_name () in
+  if Sys.file_exists file then
+    with_tmp_file_job fjob
+  else
+    OpamProcess.Job.finally (fun () -> remove_file file) (fun () -> fjob file)
+
 let remove file =
   if (try Sys2.is_directory file with Sys_error _ -> false) then
     remove_dir file
@@ -485,14 +541,6 @@ let get_cygpath_path_transform =
   else
     Lazy.from_val (fun ~pathlist:_ x -> x)
 
-let runs = ref []
-let print_stats () =
-  match !runs with
-  | [] -> ()
-  | l  ->
-    OpamConsole.msg "%d external processes called:\n%s"
-      (List.length l) (OpamStd.Format.itemize ~bullet:"  " (String.concat " ") l)
-
 let log_file ?dir name = temp_file ?dir (OpamStd.Option.default "log" name)
 
 let make_command
@@ -520,7 +568,6 @@ let run_process
     ?verbose ?env ~name ?metadata ?stdout ?allow_stdin command =
   let env = match env with None -> OpamProcess.default_env () | Some e -> e in
   let chrono = OpamConsole.timer () in
-  runs := command :: !runs;
   match command with
   | []          -> invalid_arg "run_process"
   | cmd :: args ->
@@ -595,17 +642,15 @@ let copy_file_t ?(with_log=true) src dst =
   if file_or_symlink_exists dst
   then remove_file dst;
   mkdir (Filename.dirname dst);
-  if with_log || log_for_file_management () then
-    log "copy %s -> %s" src dst;
+  log ~level:(log_for_file_management with_log) "copy %s -> %s" src dst;
   copy_file_aux ~src ~dst ()
 
-let rec link_t ?(with_log=true) src dst =
+let rec link_t ~except_vcs ?(with_log=true) src dst =
   mkdir (Filename.dirname dst);
   if file_or_symlink_exists dst then
     remove_file dst;
   try
-    if with_log || log_for_file_management () then
-      log "ln -s %s %s" src dst;
+    log ~level:(log_for_file_management with_log) "ln -s %s %s" src dst;
     Unix.symlink src dst
   with Unix.Unix_error (Unix.EXDEV, _, _) ->
     (* Fall back to copy if symlinks are not supported *)
@@ -614,14 +659,13 @@ let rec link_t ?(with_log=true) src dst =
       else src
     in
     if Sys.is_directory src then
-      copy_dir_t src dst
+      copy_dir_t ~except_vcs src dst
     else
       copy_file_t src dst
 
-and copy_dir_t ?(with_log=true) src dst_dir =
-  if with_log || log_for_file_management () then
-    log "copydir %s -> %s" src dst_dir;
-  let files = get_files src in
+and copy_dir_t ~except_vcs ?(with_log=true) src dst_dir =
+  log ~level:(log_for_file_management with_log) "copydir %s -> %s" src dst_dir;
+  let files = get_files_t ~except_vcs src in
   mkdir dst_dir;
   let with_log = false in
   List.iter (fun file ->
@@ -631,10 +675,10 @@ and copy_dir_t ?(with_log=true) src dst_dir =
       | {Unix.st_kind = Unix.S_REG; _} ->
         copy_file_t ~with_log src dst
       | {Unix.st_kind = Unix.S_DIR; _} ->
-        copy_dir_t ~with_log src dst
+        copy_dir_t ~except_vcs ~with_log src dst
       | {Unix.st_kind = Unix.S_LNK; _} ->
         let src = Unix.readlink src in
-        link_t ~with_log src dst
+        link_t ~except_vcs ~with_log src dst
       | {Unix.st_kind = Unix.S_CHR; _} ->
         failwith (Printf.sprintf "Copying character devices (%s) is unsupported" src)
       | {Unix.st_kind = Unix.S_BLK; _} ->
@@ -649,7 +693,8 @@ and copy_dir_t ?(with_log=true) src dst_dir =
         OpamConsole.warning "Warning: cannot copy %s to %s" src dst_dir
     ) files
 
-let copy_dir = copy_dir_t ~with_log:true
+let copy_dir = copy_dir_t ~except_vcs:false ~with_log:true
+let copy_dir_except_vcs = copy_dir_t ~except_vcs:true ~with_log:true
 let copy_file = copy_file_t ~with_log:true
 
 let mv src dst =
@@ -662,7 +707,7 @@ let mv src dst =
   | Unix.Unix_error(Unix.EXDEV, _, _) ->
     let with_log = false in
     if Sys.is_directory src
-    then (copy_dir_t ~with_log src dst; remove_dir_t src)
+    then (copy_dir_t ~except_vcs:false ~with_log src dst; remove_dir_t src)
     else (copy_file_t ~with_log src dst; remove_file_t ~with_log src)
 
 let is_exec file =
@@ -810,18 +855,12 @@ let install ?(warning=default_install_warning) ?exec src dst =
     copy_file_aux ~chmod:(fun _ -> perm) ~src ~dst ()
 
 let cpu_count () =
-  try
-    let ans =
-      let open OpamStd in
-      match Sys.os () with
-      | Sys.Win32 -> [Env.get "NUMBER_OF_PROCESSORS"]
-      | Sys.FreeBSD -> read_command_output ~verbose:(verbose_for_base_commands ())
-                         ["sysctl"; "-n"; "hw.ncpu"]
-      | _ -> read_command_output ~verbose:(verbose_for_base_commands ())
-               ["getconf"; "_NPROCESSORS_ONLN"]
-    in
-    int_of_string (List.hd ans)
-  with Not_found | Process_error _ | Failure _ -> 1
+  let nproc = Nativeint.to_int (OpamStubs.nproc ()) in
+  if nproc < 1 then begin
+    log "OpamStubs.nproc failed";
+    1
+  end else
+    nproc
 
 open OpamProcess.Job.Op
 
@@ -1554,57 +1593,89 @@ let translate_patch ~dir orig corrected =
   end;
   close_in ch
 
-let gpatch = lazy begin
-  let rec search_gpatch = function
-    | [] -> None
-    | patch_cmd::patch_cmds ->
-      match OpamProcess.run (make_command ~name:"patch" patch_cmd ["--version"]) with
-      | r ->
-        (match OpamProcess.is_success r, r.OpamProcess.r_stdout with
-         | true, full::_ when
-             OpamStd.String.is_prefix_of ~from:0 ~full "GNU patch " ->
-           Some patch_cmd
-         | _ ->
-           search_gpatch patch_cmds)
-      | exception _ -> search_gpatch patch_cmds
-  in
-  let default_cmd, other_cmds =
-    match OpamStd.Sys.os () with
-    | DragonFly
-    | FreeBSD
-    | NetBSD
-    | OpenBSD -> ("gpatch", ["patch"])
-    | Cygwin
-    | Darwin
-    | Linux
-    | Unix
-    | Win32
-    | Other _ -> ("patch", ["gpatch"])
-  in
-  match search_gpatch (default_cmd :: other_cmds) with
-  | Some gpatch -> gpatch
-  | None ->
-    OpamConsole.warning "Invalid patch utility. Please install GNU patch";
-    default_cmd
-end
+exception Internal_patch_error of string
 
-let patch ?(preprocess=true) ~dir p =
-  if not (Sys.file_exists p) then
-    (OpamConsole.error "Patch file %S not found." p;
-     raise Not_found);
-  let p' =
-    if preprocess then
-      let p' = temp_file ~auto_clean:false "processed-patch" in
-      translate_patch ~dir p p';
-      p'
-    else
-      p
+let patch ~allow_unclean ?patch_filename ~dir diffs =
+  let internal_patch_error fmt =
+    Printf.ksprintf (fun str -> raise (Internal_patch_error str)) fmt
   in
-  let patch_cmd = Lazy.force gpatch in
-  make_command ~name:"patch" ~dir patch_cmd ["-p1"; "-i"; p'] @@> fun r ->
-    if not (OpamConsole.debug ()) then Sys.remove p';
-    if OpamProcess.is_success r then Done None
-    else Done (Some (Process_error r))
+  let patch_info_path =
+    OpamStd.Option.default ("in directory "^dir) patch_filename
+  in
+  (* NOTE: It is important to keep this `concat dir ""` to ensure the
+     is_prefix_of below doesn't match another similarly named directory *)
+  let dir = Filename.concat (real_path dir) "" in
+  let get_path file =
+    let file = real_path (Filename.concat dir file) in
+    if not (OpamStd.String.is_prefix_of ~from:0 ~full:file dir) then
+      internal_patch_error "Patch %S tried to escape its scope."
+        patch_info_path;
+    file
+  in
+  let patch ~file content diff =
+    (* NOTE: The None case returned by [Patch.patch] is only returned
+       if [diff = Patch.Delete _]. This sub-function is not called in
+       this case so we [assert false] instead. *)
+    match Patch.patch ~cleanly:true content diff with
+    | Some x -> x
+    | None -> assert false (* See NOTE above *)
+    | exception _ when not allow_unclean ->
+      internal_patch_error "Patch %S does not apply cleanly."
+        patch_info_path
+    | exception _ ->
+      match Patch.patch ~cleanly:false content diff with
+      | Some x ->
+        Option.iter (write (file^".orig")) content;
+        x
+      | None -> assert false (* See NOTE above *)
+      | exception _ ->
+        Option.iter (write (file^".orig")) content;
+        write (file^".rej") (Format.asprintf "%a" Patch.pp diff);
+        internal_patch_error "Patch %S does not apply cleanly."
+          patch_info_path
+  in
+  let apply diff = match diff.Patch.operation with
+    | Patch.Edit (file1, file2) ->
+      let file1 = get_path file1 in
+      let file2 = get_path file2 in
+      let file1_exists = Sys.file_exists file1 in
+      (* That seems to be the GNU patch behaviour *)
+      let file = if file1_exists then file1 else file2 in
+      let content = read file in
+      let content = patch ~file:file (Some content) diff in
+      write file content;
+      if file1_exists && file1 <> (file2 : string) then
+        rmdir_cleanup (Filename.dirname file1)
+    | Patch.Delete file | Patch.Git_ext (file, _, Patch.Delete_only) ->
+      let file = get_path file in
+      remove_file_t ~with_log:false file;
+      rmdir_cleanup (Filename.dirname file)
+    | Patch.Create file | Patch.Git_ext (_, file, Patch.Create_only) ->
+      let file = get_path file in
+      let content = patch ~file None diff in
+      write file content
+    | Patch.Git_ext (_, _, Patch.Rename_only (src, dst)) ->
+      let src = get_path src in
+      let dst = get_path dst in
+      mv src dst;
+      let dirname_src = Filename.dirname src in
+      if dirname_src <> (Filename.dirname dst : string) then
+        rmdir_cleanup dirname_src
+  in
+  List.iter apply diffs
+
+let parse_patch ~dir ~file =
+  if not (Sys.file_exists file) then
+    (OpamConsole.error "Patch file %S not found." file;
+     raise Not_found);
+  let file' =
+    let file' = temp_file ~auto_clean:false "processed-patch" in
+    translate_patch ~dir file file';
+    file'
+  in
+  let content = read file' in
+  Fun.protect (fun () -> Patch.parse ~p:1 content)
+    ~finally:(fun () -> if not (OpamConsole.debug ()) then Sys.remove file')
 
 let register_printer () =
   Printexc.register_printer (function
