@@ -12,7 +12,6 @@
 open OpamParserTypes.FullPos
 open OpamTypes
 open OpamTypesBase
-open OpamStd.Op
 open OpamPp
 open OpamPp.Op
 
@@ -24,8 +23,8 @@ let values_pos = function
   | [] -> None
   | x::_ -> Some (value_pos x)
 
-let optelem = OpamStd.Option.map (fun x -> x.pelem)
-let nullposelem = OpamStd.Option.map nullify_pos
+let optelem = Option.map (fun x -> x.pelem)
+let nullposelem = Option.map nullify_pos
 
 (** low-level Pps for the Lines parser ([string list list]) *)
 
@@ -781,7 +780,7 @@ module I = struct
                | Bad_format (pos, msg) ->
                  (field, (pos, msg)) :: errs, acc
              with Not_found ->
-               (if List.mem field mandatory_fields
+               (if OpamStd.List.mem String.equal field mandatory_fields
                 then (field, (Some pos, "Missing field "^field)) :: errs
                 else errs),
                acc)
@@ -806,7 +805,7 @@ module I = struct
       r, errs
     in
     let print (acc, _) =
-      OpamStd.List.filter_map
+      List.filter_map
         (fun (field,ppa) ->
            match snd (ppa.print acc) with
            | None | Some ({ pelem = List { pelem = []; _}; _}
@@ -875,7 +874,7 @@ module I = struct
     pp
       (fun ~pos items ->
          match
-           OpamStd.List.filter_map (fun v -> match v.pelem with
+           List.filter_map (fun v -> match v.pelem with
                | Variable (k,v) when k.pelem = name -> Some v
                | _ -> None)
              items
