@@ -35,9 +35,14 @@ let string_of_atom = function
       (string_of_relop r)
       (OpamPackage.Version.to_string c)
 
+(* TODO: upstream to opam-file-format *)
 let compare_relop x y =
   Stdlib.compare (x : [`Eq|`Neq|`Geq|`Gt|`Leq|`Lt]) (y : relop)
 
+(* TODO: upstream to opam-file-format *)
+let equal_relop x y =
+  compare_relop x y = 0
+
 let compare_version_constraint (relop1, v1) (relop2, v2) =
   let cmp = compare_relop relop1 relop2 in
   if cmp <> 0 then cmp
@@ -79,11 +84,10 @@ let atom_of_string =
       let sop = Re.Group.get sub 2 in
       let sversion = Re.Group.get sub 3 in
       let name = OpamPackage.Name.of_string sname in
-      let sop = if sop = "." then "=" else sop in
-      let op = OpamLexer.FullPos.relop sop in
+      let op = if sop = "." then `Eq else OpamLexer.FullPos.relop sop in
       let version = OpamPackage.Version.of_string sversion in
       name, Some (op, version)
-    with Not_found | Failure _ | OpamLexer.Error _ ->
+    with Not_found | OpamLexer.Error _ ->
       OpamPackage.Name.of_string str, None
 
 type 'a conjunction = 'a list
@@ -272,6 +276,8 @@ let compare_nc (n1, c1) (n2, c2) =
 
 let compare = compare_formula compare_nc
 
+let equal f1 f2 = compare f1 f2 = 0
+
 let rec eval atom = function
   | Empty    -> true
   | Atom x   -> atom x
