@@ -9,8 +9,6 @@
 (*                                                                        *)
 (**************************************************************************)
 
-open OpamStd.Op
-
 let log fmt = OpamConsole.log "PACKAGE" fmt
 let slog = OpamConsole.slog
 
@@ -28,7 +26,8 @@ module Version = struct
         | 'a'..'z' | 'A'..'Z' | '0'..'9' | '-' | '_' | '+' | '.' | '~' -> ()
         | c ->
           failwith
-            (Printf.sprintf "Invalid character '%c' in package version %S" c x))
+            (Printf.sprintf "Invalid character '%s' in package version %S"
+               (Char.escaped c) x))
       x;
     x
 
@@ -66,22 +65,20 @@ module Name = struct
   let to_string x = x
 
   let of_string x =
-    match
-      OpamStd.String.fold_left (fun acc c ->
-          if acc = Some false then acc else match c with
-            | 'a'..'z' | 'A'..'Z' -> Some true
-            | '0'..'9' | '-' | '_' | '+' -> acc
-            | _ -> Some false)
-        None x
-    with
-    | Some false ->
+    if
+      OpamCompat.String.fold_left (fun acc c ->
+          match c with
+          | 'a'..'z' | 'A'..'Z' -> false
+          | '0'..'9' | '-' | '_' | '+' -> acc
+          | c ->
+            failwith
+              (Printf.sprintf "Invalid character '%s' in package name %S"
+                 (Char.escaped c) x))
+        true x
+    then
       failwith
-        (Printf.sprintf "Invalid character in package name %S" x)
-    | None ->
-      failwith
-        (Printf.sprintf "Package name %S should contain at least one letter" x)
-    | Some true ->
-      x
+        (Printf.sprintf "Package name %S should contain at least one letter" x);
+    x
 
   let compare = OpamStd.String.compare_case
 
@@ -124,8 +121,8 @@ let version t = t.version
 let sep = '.'
 
 let of_string_opt s =
-  if OpamStd.String.contains_char s ' ' ||
-     OpamStd.String.contains_char s '\n' then
+  if String.contains s ' ' ||
+     String.contains s '\n' then
     None
   else match OpamStd.String.cut_at s sep with
     | None        -> None
