@@ -71,7 +71,7 @@ let plugins_bin t = plugins t / "bin"
 let plugin_bin t name =
   let sname = OpamPackage.Name.to_string name ^ OpamStd.Sys.executable_name "" in
   let basename =
-    if OpamStd.String.starts_with ~prefix:plugin_prefix sname then sname
+    if OpamCompat.String.starts_with ~prefix:plugin_prefix sname then sname
     else plugin_prefix ^ sname
   in
   plugins_bin t // basename
@@ -146,6 +146,8 @@ module Switch = struct
 
   let env_relative_to_prefix pfx = pfx / meta_dirname /- env_filename
 
+  let nix_env t a = meta t a /- "nix.env"
+
   let installed_opams t a = meta t a / "packages"
 
   let installed_opams_cache t a = meta t a / "packages" // "cache"
