@@ -1,6 +1,6 @@
 (**************************************************************************)
 (*                                                                        *)
-(*    Copyright 2012-2015 OCamlPro                                        *)
+(*    Copyright 2012-2016 OCamlPro                                        *)
 (*    Copyright 2012 INRIA                                                *)
 (*                                                                        *)
 (*  All rights reserved. This file is distributed under the terms of the  *)
@@ -17,7 +17,7 @@ open OpamTypes
 
 val rsync_dirs: ?args:string list -> ?exclude_vcdirs:bool ->
   OpamUrl.t -> OpamFilename.Dir.t ->
-  OpamFilename.Dir.t download OpamProcess.job
+  unit download OpamProcess.job
 val rsync_file: ?args:string list ->
   OpamUrl.t -> OpamFilename.t ->
-  OpamFilename.t download OpamProcess.job
+  unit download OpamProcess.job
