@@ -52,7 +52,7 @@ let link_files ~target f l =
 let fetch_from_cache =
   let currently_downloading = ref [] in
   let rec no_concurrent_dls key f x =
-    if List.mem key !currently_downloading then
+    if OpamStd.List.mem OpamHash.equal key !currently_downloading then
       Run (OpamProcess.command "sleep" ["1"],
            (fun _ -> no_concurrent_dls key f x))
     else
@@ -91,7 +91,7 @@ let fetch_from_cache =
           OpamProcess.Job.Op.Done ()
         | None ->
           (OpamLocal.rsync_file url file @@| function
-            | Result _ | Up_to_date _-> ()
+            | Result () | Up_to_date () -> ()
             | Not_available (s,l) -> raise (OpamDownload.Download_fail (s,l)))
       end
     | #OpamUrl.version_control ->
@@ -308,7 +308,7 @@ let pull_tree_t
         OpamFilename.extract_job archive tmpdir
         @@+ fallback (fun () ->
             let failing =
-              OpamStd.List.filter_map (function
+              List.filter_map (function
                   | Result _ | Up_to_date _ -> None
                   | Not_available (Some s,l) -> Some (s,l)
                   | Not_available (None, _) -> assert false
@@ -490,7 +490,7 @@ let validate_repo_update repo repo_root update =
         | "anchors", _ -> Some (S (String.concat "," ta.fingerprints))
         | "quorum", _ -> Some (S (string_of_int ta.quorum))
         | "repo", _ -> Some (S (OpamFilename.Dir.to_string repo_root))
-        | "patch", Update_patch f -> Some (S (OpamFilename.to_string f))
+        | "patch", Update_patch (f, _)  -> Some (S (OpamFilename.to_string f))
         | "incremental", Update_patch _ -> Some (B true)
         | "incremental", _ -> Some (B false)
         | "dir", Update_full d -> Some (S (OpamFilename.Dir.to_string d))
@@ -524,8 +524,8 @@ let apply_repo_update repo repo_root = function
     OpamConsole.msg "[%s] Initialised\n"
       (OpamConsole.colorise `green
          (OpamRepositoryName.to_string repo.repo_name));
-    Done ()
-  | Update_patch f ->
+    Done []
+  | Update_patch (f, diffs)  ->
     OpamConsole.msg "[%s] synchronised from %s\n"
       (OpamConsole.colorise `green
          (OpamRepositoryName.to_string repo.repo_name))
@@ -533,16 +533,13 @@ let apply_repo_update repo repo_root = function
     log "%a: applying patch update at %a"
       (slog OpamRepositoryName.to_string) repo.repo_name
       (slog OpamFilename.to_string) f;
-    let preprocess =
-      match repo.repo_url.OpamUrl.backend with
-      | `http | `rsync -> false
-      | _ -> true
+    let patch_result =
+      OpamFilename.patch ~allow_unclean:false (`Patch_diffs diffs) repo_root
     in
-    (OpamFilename.patch ~preprocess f repo_root @@+ function
-      | Some e ->
-        if not (OpamConsole.debug ()) then OpamFilename.remove f;
-        raise e
-      | None -> OpamFilename.remove f; Done ())
+    if not (OpamConsole.debug ()) then OpamFilename.remove f;
+    (match patch_result with
+     | Ok diffs -> Done diffs
+     | Error e -> raise e)
   | Update_empty ->
     OpamConsole.msg "[%s] no changes from %s\n"
       (OpamConsole.colorise `green
@@ -550,14 +547,14 @@ let apply_repo_update repo repo_root = function
       (OpamUrl.to_string repo.repo_url);
     log "%a: applying empty update"
       (slog OpamRepositoryName.to_string) repo.repo_name;
-    Done ()
+    Done []
   | Update_err _ -> assert false
 
 let cleanup_repo_update upd =
   if not (OpamConsole.debug ()) then
     match upd with
     | Update_full d -> OpamFilename.rmdir d
-    | Update_patch f -> OpamFilename.remove f
+    | Update_patch (f, _) -> OpamFilename.remove f
     | _ -> ()
 
 let update repo repo_root =
@@ -567,7 +564,8 @@ let update repo repo_root =
   | Update_err e -> raise e
   | Update_empty ->
     log "update empty, no validation performed";
-    apply_repo_update repo repo_root Update_empty @@+ fun () ->
+    apply_repo_update repo repo_root Update_empty @@+ fun diffs ->
+    assert (diffs = []);
     B.repo_update_complete repo_root repo.repo_url @@+ fun () ->
     Done `No_changes
   | (Update_full _ | Update_patch _) as upd ->
@@ -580,9 +578,9 @@ let update repo repo_root =
       cleanup_repo_update upd;
       failwith "Invalid repository signatures, update aborted"
     | true ->
-      apply_repo_update repo repo_root upd @@+ fun () ->
+      apply_repo_update repo repo_root upd @@+ fun diffs ->
       B.repo_update_complete repo_root repo.repo_url @@+ fun () ->
-      Done `Changes
+      Done (`Changes diffs)
 
 let on_local_version_control url ~default f =
   match url.OpamUrl.backend with
