@@ -23,10 +23,13 @@ val packages_with_prefixes: dirname -> string option package_map
 (** {2 Repository backends} *)
 
 (** Update {i $opam/repo/$repo}. Returns [`No_changes] if the update did not
-    bring any changes, and [`Changes] otherwise.
+    bring any changes, and [`Changes of Patch.operation list]
+    representing creations, deletions, and modifications of regular files.
 
     @raise Failure in case the update couldn't be achieved. *)
-val update: repository -> dirname -> [`Changes | `No_changes] OpamProcess.job
+val update:
+  repository -> dirname ->
+  [`Changes of Patch.operation list |`No_changes] OpamProcess.job
 
 (** [pull_shared_tree ?cache_dir ?cache_url labels_dirnames checksums urls]
     Fetch an URL and put the resulting tree into the supplied directories
