@@ -1097,7 +1097,7 @@ let extract_explanations packages cudfnv2opam reasons : explanation list =
         let x, xs =
           List.fold_left (fun ((s, l, b) as x, xs) -> function
               | `Conflict ((s', l', b') as y) ->
-                if OpamStd.Option.equal String.equal s s' &&
+                if Stdlib.Option.equal String.equal s s' &&
                    Bool.equal b b' then
                   match List.map2 (List.map2 simplify_cst) l l' with
                   | new_l -> ((s, new_l, b), xs)
@@ -1311,7 +1311,7 @@ let remove_all_uninstalled_versions_but universe name constr =
 let to_cudf univ (req: Cudf_types.vpkg request) =
   let install =
     let conj = OpamFormula.ands_to_list req.wish_install in
-    OpamStd.List.filter_map (function
+    List.filter_map (function
         | Atom vpkg -> Some vpkg
         | Empty -> None
         | _ -> invalid_arg "OpamCudf.to_cudf: 'install' not a conjunction")
@@ -1595,9 +1595,12 @@ let call_external_solver ~version_map univ req =
       let msg =
         Printf.sprintf
           "Sorry, resolution of the request timed out.\n\
-           Try to specify a more precise request, use a different solver, or \
-           increase the allowed time by setting OPAMSOLVERTIMEOUT to a bigger \
+           Try to specify a more precise request, use a different solver, \
+           increase the tolerance for unoptimized solutions by setting \
+           OPAMSOLVERTOLERANCE to a bigger value (currently, it is set to %.1f) \
+           or increase the allowed time by setting OPAMSOLVERTIMEOUT to a bigger \
            value (currently, it is set to %.1f seconds)."
+          OpamSolverConfig.(OpamStd.Option.default 0. !r.solver_tolerance)
           OpamSolverConfig.(OpamStd.Option.default 0. !r.solver_timeout)
       in
       raise (Solver_failure msg)
@@ -1796,7 +1799,8 @@ let compute_root_causes g requested reinstall available =
     if c2 = Unknown || depth1 < depth2 then c1, depth1 else
     if c1 = Unknown || depth2 < depth1 then c2, depth2 else
     let (@) =
-      List.fold_left (fun l a -> if List.mem a l then l else a::l)
+      List.fold_left (fun l a ->
+          if OpamStd.List.mem Cudf.( =% ) a l then l else a::l)
     in
     match c1, c2 with
     | Required_by a, Required_by b -> Required_by (a @ b), depth1
