@@ -437,7 +437,7 @@ let global_env_keys = lazy (
 
 let updates_from_previous_instance = lazy (
   let get_env env_file =
-    OpamStd.Option.map
+    Option.map
       (map_update_names (Lazy.force global_env_keys))
       (OpamFile.Environment.read_opt env_file)
   in
@@ -539,7 +539,7 @@ let expand updates =
       in
       let var = OpamStd.Env.Name.of_string svar in
       let zip, reverts =
-        match OpamStd.List.find_opt (fun (v, _, _, _) ->
+        match List.find_opt (fun (v, _, _, _) ->
             OpamStd.Env.Name.equal var v) acc with
         | Some (_, z, _doc, _) -> z, reverts
         | None ->
@@ -970,7 +970,7 @@ let env_hook_script_base = function
   | SH_fish -> Some OpamScript.env_hook_fish
   | SH_pwsh _ | SH_cmd -> None
 
-let export_in_shell shell =
+let export_in_shell ~unconditional shell =
   let make_comment comment_opt =
     OpamStd.Option.to_string (Printf.sprintf "# %s\n") comment_opt
   in
@@ -978,8 +978,12 @@ let export_in_shell shell =
     Printf.sprintf "%s%s=%s; export %s;\n"
       (make_comment comment) k v k in
   let csh  (k,v,comment) =
-    Printf.sprintf "%sif ( ! ${?%s} ) setenv %s \"\"\nsetenv %s %s\n"
-      (make_comment comment) k k k v in
+    if unconditional then
+      Printf.sprintf "%ssetenv %s %s\n"
+        (make_comment comment) k v
+    else
+      Printf.sprintf "%sif ( ! ${?%s} ) setenv %s \"\"\nsetenv %s %s\n"
+        (make_comment comment) k k k v in
   let fish (k,v,comment) =
     (* Fish converts some colon-separated vars to arrays, which have to be
        treated differently. MANPATH is handled automatically, so better not to
@@ -1021,11 +1025,28 @@ let export_in_shell shell =
   | SH_cmd -> cmd
 
 let env_hook_script shell =
-  OpamStd.Option.map (fun script ->
-      export_in_shell shell ("OPAMNOENVNOTICE", "true", None)
+  Option.map (fun script ->
+      export_in_shell shell ~unconditional:true ("OPAMNOENVNOTICE", "true", None)
       ^ script)
     (env_hook_script_base shell)
 
+let abort_if_set var shell =
+  (* Each of these incantations aborts the currently running script if [var] is
+     unset or empty ("null") *)
+  match shell with
+  | SH_zsh | SH_bash | SH_sh ->
+    Printf.sprintf "test -z \"${%s:+x}\" || return\n" var
+  | SH_csh ->
+    Printf.sprintf "if ( ${?%s} ) then\n  if ( \"$%s\" != \"\") exit\nendif\n"
+      var var
+  | SH_pwsh _ ->
+    Printf.sprintf "if ($env:%s -ne $null -and $env:%s -ne '') { return }\n"
+      var var
+  | SH_fish ->
+    Printf.sprintf "test -z \"$%s\"; or return\n" var
+  | SH_cmd ->
+    Printf.sprintf "if defined %s if \"%%%s%%\" neq \"\" goto :EOF\n" var var
+
 let source root shell f =
   let fname = OpamFilename.to_string (OpamPath.init root // f) in
   let unix_transform ?using_backslashes () =
@@ -1129,7 +1150,7 @@ let string_of_update st shell updates =
          | SH_cmd -> Printf.sprintf "%%%s%%%c%s" envu_var sep string
          | _ -> Printf.sprintf "\"$%s\":'%s'" envu_var string)
     in
-    export_in_shell shell (key, value, envu_comment) in
+    export_in_shell shell ~unconditional:(envu_op = Eq) (key, value, envu_comment) in
   OpamStd.List.concat_map "" aux updates
 
 let write_script dir (name, body) =
@@ -1149,7 +1170,7 @@ let write_static_init_scripts root ?completion ?env_hook ?(inplace=false) () =
   write_init_shell_scripts root;
   let update_scripts filef scriptf enable =
     let scripts =
-      OpamStd.List.filter_map (fun shell ->
+      List.filter_map (fun shell ->
           match filef shell, scriptf shell with
           | Some f, Some s -> Some (f, s)
           | _ -> None)
@@ -1219,7 +1240,9 @@ let write_dynamic_init_scripts st =
     List.iter
       (fun shell ->
          write_script (OpamPath.init st.switch_global.root)
-           (variables_file shell, string_of_update st shell updates))
+           (variables_file shell,
+            abort_if_set "OPAM_SWITCH_PREFIX" shell
+            ^ string_of_update st shell updates))
       [SH_sh; SH_csh; SH_fish; SH_pwsh Powershell; SH_cmd]
   with OpamSystem.Locked ->
     OpamConsole.warning
@@ -1251,11 +1274,13 @@ let dot_profile_needs_update root dot_profile =
 let update_dot_profile root dot_profile shell =
   let pretty_dot_profile = OpamFilename.prettify dot_profile in
   let bash_src () =
-    if (shell = SH_bash || shell = SH_sh)
-    && OpamFilename.(Base.to_string (basename dot_profile)) <> ".bashrc" then
-      OpamConsole.note "Make sure that %s is well %s in your ~/.bashrc.\n"
-        pretty_dot_profile
-        (OpamConsole.colorise `underline "sourced")
+    if shell = SH_bash then
+      let bash_dot_profile =
+        OpamFilename.prettify
+          (OpamFilename.of_string (OpamStd.Sys.guess_bash_dot_profile ()))
+      in
+      OpamConsole.note "Make sure that ~/.bashrc is well %s in your %s.\n"
+        (OpamConsole.colorise `underline "sourced") bash_dot_profile
   in
   match dot_profile_needs_update root dot_profile with
   | `no        -> OpamConsole.msg "  %s is already up-to-date.\n" pretty_dot_profile; bash_src()
@@ -1291,7 +1316,7 @@ let update_dot_profile root dot_profile shell =
 let update_user_setup root ?dot_profile shell =
   if dot_profile <> None then (
     OpamConsole.msg "\nUser configuration:\n";
-    OpamStd.Option.iter (fun f -> update_dot_profile root f shell) dot_profile
+    Option.iter (fun f -> update_dot_profile root f shell) dot_profile
   )
 
 let check_and_print_env_warning st =
@@ -1356,7 +1381,7 @@ let setup
          \n\
         \  You can always re-run this setup with 'opam init' later.\n\n"
         (OpamConsole.colorise `bold @@ shell_eval_invocation shell (opam_env_invocation shell));
-      if OpamCoreConfig.answer_is_yes () then begin
+      if OpamCoreConfig.answer_is_yes ~name:None () then begin
         if dot_profile <> None then
           OpamConsole.warning "Shell not updated in non-interactive mode: use --shell-setup";
         shell, None, env_hook
@@ -1402,7 +1427,7 @@ let setup
               "Please select a shell to configure"
               ~options: (List.map (fun s -> s, string_of_shell s) OpamStd.Sys.all_shells)
           in
-          menu shell (OpamStd.Option.map OpamFilename.of_string (OpamStd.Sys.guess_dot_profile shell))
+          menu shell (Option.map OpamFilename.of_string (OpamStd.Sys.guess_dot_profile shell))
             default
         | `Change_file ->
           let open OpamStd.Option.Op in
