@@ -59,7 +59,8 @@ val files_in_source_w_target:
 val name_of_opam_filename: ?locked:string -> dirname -> filename -> name option
 
 (** Finds back the location of the opam file this package definition was loaded
-    from *)
+    from. As it read from repository, use this function if you need to preserve
+    format, otherwise prefer {OpamSwitchState.overlay_opam_file}. *)
 val orig_opam_file:
   'a switch_state -> OpamPackage.Name.t -> OpamFile.OPAM.t ->
   OpamFile.OPAM.t OpamFile.t option
