@@ -89,7 +89,8 @@ let infer_switch_invariant_raw
     else compiler
   in
   let env nv v =
-    if List.mem v OpamPackageVar.predefined_depends_variables then
+    if OpamStd.List.mem OpamVariable.Full.equal
+        v OpamPackageVar.predefined_depends_variables then
       match OpamVariable.Full.to_string v with
       | "dev" | "with-test" | "with-doc" | "with-dev-setup" -> Some (B false)
       | _ -> None
@@ -233,7 +234,6 @@ let depexts_unavailable_raw sys_packages nv =
   | _ -> None
 
 let load lock_kind gt rt switch =
-  OpamFormatUpgrade.as_necessary_repo_switch_light_upgrade lock_kind `Switch gt;
   let chrono = OpamConsole.timer () in
   log "LOAD-SWITCH-STATE %@ %a" (slog OpamSwitch.to_string) switch;
   if not (OpamGlobalState.switch_exists gt switch) then
@@ -259,7 +259,11 @@ let load lock_kind gt rt switch =
   let lock =
     OpamFilename.flock lock_kind (OpamPath.Switch.lock gt.root switch)
   in
-  let switch_config = load_switch_config ~lock_kind gt switch in
+  let switch_config =
+    match OpamFormatUpgrade.as_necessary_switch lock_kind switch gt with
+    | Some switch_config -> switch_config
+    | None -> load_switch_config ~lock_kind gt switch
+  in
   if OpamStateConfig.is_newer_than_self ~lock_kind gt then
     log "root version (%s) is greater than running binary's (%s); \
          load with best-effort (read-only)"
@@ -717,15 +721,6 @@ let primary_url_with_subpath st nv =
     | Some subpath ->
       Some OpamUrl.Op.(url / (OpamFilename.SubPath.to_string subpath))
 
-let files st nv =
-  match opam_opt st nv with
-  | None -> []
-  | Some opam ->
-    List.map (fun (file,_base,_hash) -> file)
-      (OpamFile.OPAM.get_extra_files
-         ~repos_roots:(OpamRepositoryState.get_root st.switch_repos)
-         opam)
-
 let package_config st name =
   OpamPackage.Name.Map.find name st.conf_files
 
@@ -774,6 +769,16 @@ let source_dir st nv =
   then OpamPath.Switch.pinned_package st.switch_global.root st.switch nv.name
   else OpamPath.Switch.sources st.switch_global.root st.switch nv
 
+let overlay_opam_file st name =
+  if is_pinned st name then
+    let file =
+      OpamPath.Switch.Overlay.opam st.switch_global.root st.switch name
+    in
+    if OpamFile.exists file then
+      Some file
+    else None
+  else None
+
 let depexts st nv =
   let env v = OpamPackageVar.resolve_switch ~package:nv st v in
  depexts_raw ~env nv st.opams
@@ -902,7 +907,8 @@ let undefined_filter_variable nv v =
 
 let package_env_t st ~force_dev_deps ~test ~doc ~dev_setup
     ~requested_allpkgs ?(err_undefined=true) nv v =
-  if List.mem v OpamPackageVar.predefined_depends_variables then
+  if OpamStd.List.mem OpamVariable.Full.equal
+      v OpamPackageVar.predefined_depends_variables then
     match OpamVariable.Full.to_string v with
     | "dev" ->
       Some (B (force_dev_deps || is_dev_package st nv))
@@ -923,7 +929,8 @@ let get_dependencies_t st ~force_dev_deps ~test ~doc ~dev_setup
     ~requested_allpkgs deps opams =
   let filter_undefined nv =
     let warn_undefined v =
-      if not (List.mem v OpamPackageVar.predefined_depends_variables) then
+      if not (OpamStd.List.mem OpamVariable.Full.equal
+                v OpamPackageVar.predefined_depends_variables) then
         undefined_filter_variable nv v
     in
     OpamFormula.map (fun (name, fc) ->
@@ -1342,7 +1349,8 @@ let update_repositories gt update_fun switch =
 
 let dependencies_filter_to_formula_t ~build ~post st nv =
   let env v =
-    if List.mem v OpamPackageVar.predefined_depends_variables then
+    if OpamStd.List.mem OpamVariable.Full.equal
+        v OpamPackageVar.predefined_depends_variables then
       match OpamVariable.Full.to_string v with
       | "build" -> Some (B build)
       | "post" -> Some (B post)
