@@ -67,7 +67,7 @@ let repository rt repo =
     in
     OpamProcess.Job.with_text text @@
     OpamRepository.update r repo_root @@+ fun has_changes ->
-    let has_changes = if redirect then `Changes else has_changes in
+    let has_changes = if redirect then `Changes [] else has_changes in
     if n <> max_loop && r = repo then
       (OpamConsole.warning "%s: Cyclic redirections, stopping."
          (OpamRepositoryName.to_string repo.repo_name);
@@ -99,7 +99,7 @@ let repository rt repo =
   | `No_changes ->
     log "Repository did not change: nothing to do.";
     Done None
-  | `Changes ->
+  | `Changes diffs ->
     log "Repository has new changes";
     let repo_file = OpamFile.Repo.safe_read repo_file_path in
     let repo_file = OpamFile.Repo.with_root_url repo.repo_url repo_file in
@@ -134,7 +134,10 @@ let repository rt repo =
         (Printexc.to_string e)
     | None ->
       let opams =
-        OpamRepositoryState.load_opams_from_dir repo.repo_name repo_root
+        match diffs with
+        | [] ->
+          OpamRepositoryState.load_opams_from_dir repo.repo_name repo_root
+        | diffs -> OpamRepositoryState.load_opams_from_diff repo diffs rt
       in
       let local_dir = OpamRepositoryPath.root gt.root repo.repo_name in
       if OpamRepositoryConfig.(!r.repo_tarring) then
@@ -235,7 +238,7 @@ let pinned_package st ?version ?(autolock=false) ?(working_dir=false) name =
        from the repo *)
     let add_extra_files srcdir file opam =
       if OpamFilename.dirname (OpamFile.filename file) <> srcdir
-      then OpamFileTools.add_aux_files ~files_subdir_hashes:true opam
+      then OpamFileTools.add_aux_files ~files_subdir_hashes:false opam
       else opam
     in
     let locked = if autolock then OpamFile.OPAM.locked opam else None in
@@ -348,16 +351,15 @@ let pinned_package st ?version ?(autolock=false) ?(working_dir=false) name =
         then OpamFile.OPAM.with_version version opam
         else opam
       in
-      List.iter (fun (file, rel_file, hash) ->
-          if OpamFilename.exists file &&
-             OpamHash.check_file (OpamFilename.to_string file) hash then
-            OpamFilename.copy ~src:file
-              ~dst:(OpamFilename.create files_dir rel_file)
-          else
+      List.iter (fun (rel_file, content, hash) ->
+          match content with
+          | Some (lazy content) when OpamHash.check_string content hash ->
+            OpamFilename.write (OpamFilename.create files_dir rel_file) content
+          | None | Some _ ->
             OpamConsole.warning "Ignoring file %s with invalid hash"
-              (OpamFilename.to_string file))
+              (OpamFilename.Base.to_string rel_file))
         (OpamFile.OPAM.get_extra_files
-           ~repos_roots:(OpamRepositoryState.get_root st.switch_repos)
+           ~get_repo_files:(OpamRepositoryState.get_repo_files st.switch_repos)
            opam);
       OpamFile.OPAM.write opam_file
         (OpamFile.OPAM.with_extra_files_opt None opam);
@@ -464,7 +466,7 @@ let dev_packages st ?autolock ?(working_dir=OpamPackage.Set.empty) packages =
   (* The following is needed for pinned packages that may have changed
      version *)
   let selections1 = OpamSwitchState.selections st in
-  if selections0 <> selections1 then
+  if not (OpamTypesBase.switch_selections_equal selections0 selections1) then
     OpamFile.SwitchSelections.write
       (OpamPath.Switch.selections st.switch_global.root st.switch)
       selections1;
@@ -513,24 +515,28 @@ let active_caches st nvs =
         match OpamRepositoryState.find_package_opt rt repos_list nv with
         | None -> acc
         | Some (repo, _) ->
-          if List.mem repo repos then acc else
-          let repo_def = OpamRepositoryName.Map.find repo rt.repos_definitions in
-          let root_url = match OpamFile.Repo.root_url repo_def with
-            | None -> OpamSystem.internal_error "repo file of unknown origin"
-            | Some u -> u
-          in
-          let cache =
-            OpamStd.List.filter_map (fun rel ->
-                if OpamStd.String.contains ~sub:"://" rel
-                then
-                  let r = OpamUrl.parse_opt ~handle_suffix:false rel in
-                  if r = None then
-                    OpamConsole.warning "Invalid cache url %s, skipping" rel;
-                  r
-                else Some OpamUrl.Op.(root_url / rel))
-              (OpamFile.Repo.dl_cache repo_def)
-          in
-          repo::repos, cache::caches)
+          if OpamStd.List.mem OpamRepositoryName.equal repo repos then
+            acc
+          else
+            let repo_def =
+              OpamRepositoryName.Map.find repo rt.repos_definitions
+            in
+            let root_url = match OpamFile.Repo.root_url repo_def with
+              | None -> OpamSystem.internal_error "repo file of unknown origin"
+              | Some u -> u
+            in
+            let cache =
+              List.filter_map (fun rel ->
+                  if OpamStd.String.contains ~sub:"://" rel
+                  then
+                    let r = OpamUrl.parse_opt ~handle_suffix:false rel in
+                    if r = None then
+                      OpamConsole.warning "Invalid cache url %s, skipping" rel;
+                    r
+                  else Some OpamUrl.Op.(root_url / rel))
+                (OpamFile.Repo.dl_cache repo_def)
+            in
+            repo::repos, cache::caches)
       ([],[]) nvs
     |> snd
     |> List.rev
