@@ -68,6 +68,10 @@ for dir in /*; do
     *) add_sys_mounts "$dir";;
     esac
 done
+# NOTE: This is required for NixOS (see https://github.com/NixOS/nixpkgs/pull/363770)
+if [ -d /run/current-system/sw ]; then
+  add_sys_mounts /run/current-system/sw
+fi
 
 mount_linked_cache() {
   local l_cache=$1
@@ -95,7 +99,7 @@ add_ccache_mount() {
 }
 
 add_dune_cache_mount() {
-  local dune_cache=${XDG_CACHE_HOME:-$HOME/.cache}/dune
+  local dune_cache=${DUNE_CACHE_ROOT:-${XDG_CACHE_HOME:-$HOME/.cache}/dune}
   mount_linked_cache "$dune_cache"
 }
 
