@@ -107,10 +107,10 @@ type filt_sort =
 let escape_regexps s =
   let buf = Buffer.create (String.length s * 2) in
   String.iter (function
-    | ('|' | '(' | ')' | '*' | '+' | '?'
-    |  '[' | '.' | '^' | '$' | '{' | '\\') as c -> Buffer.add_char buf '\\'; Buffer.add_char buf c
-    | c -> Buffer.add_char buf c
-  ) s;
+      | '|' | '(' | ')' | '*' | '+' | '?'
+      | '[' | '.' | '^' | '$' | '{' | '\\' as c -> Buffer.add_char buf '\\'; Buffer.add_char buf c
+      | c -> Buffer.add_char buf c
+    ) s;
   Buffer.contents buf
 
 let str_replace_path ?escape whichway filters s =
@@ -170,7 +170,7 @@ let command
       else
         cmd
     in
-      maybe_resolved_cmd, cmd
+    maybe_resolved_cmd, cmd
   in
   let args =
     if orig_cmd = "tar" || orig_cmd = "tar.exe" then
@@ -206,7 +206,7 @@ let command
   if not silent && sort then
     List.iter print_endline out;
   let out = String.concat "\n" out in
-  if not (List.mem ret allowed_codes) then
+  if not (OpamStd.List.mem Int.equal ret allowed_codes) then
     raise (Command_failure (ret, String.concat " " (cmd :: args), out))
   else
     out
@@ -214,19 +214,19 @@ let command
 let finally f x k = match f x with
   | r -> k (); r
   | exception e ->
-      (* When we're at least 4.05+
-      let bt = Printexc.get_raw_backtrace () in*)
-      (try k () with _ -> ());
-      (*Printexc.raise_with_backtrace e bt*)
-      raise e
+    (* When we're at least 4.05+
+       let bt = Printexc.get_raw_backtrace () in*)
+    (try k () with _ -> ());
+    (*Printexc.raise_with_backtrace e bt*)
+    raise e
 
 (* Borrowed from ocamltest_stdlib.ml *)
 let rec mkdir_p dir =
   if Sys.file_exists dir then ()
   else let () = mkdir_p (Filename.dirname dir) in
-       if not (Sys.file_exists dir) then
-         Unix.mkdir dir 0o777
-       else ()
+    if not (Sys.file_exists dir) then
+      Unix.mkdir dir 0o777
+    else ()
 
 let erase_file path =
   try Sys.remove path
@@ -238,15 +238,15 @@ let erase_file path =
 
 let rm_rf path =
   let rec erase path =
-    if Sys.file_exists path && Sys.is_directory path then begin
+    if OpamSystem.is_reg_dir path then begin
       Array.iter (fun entry -> erase (Filename.concat path entry))
-                 (Sys.readdir path);
+        (Sys.readdir path);
       Unix.rmdir path
     end else erase_file path
   in
-    try if Sys.file_exists path then erase path
-    with Sys_error err ->
-      raise (Sys_error (Printf.sprintf "Failed to remove %S (%s)" path err))
+  try if Sys.file_exists path then erase path
+  with Sys_error err ->
+    raise (Sys_error (Printf.sprintf "Failed to remove %S (%s)" path err))
 
 let rec with_temp_dir f =
   let s =
@@ -257,8 +257,8 @@ let rec with_temp_dir f =
   if Sys.file_exists s then
     with_temp_dir f
   else
-  (mkdir_p s;
-   finally f s @@ fun () -> rm_rf s)
+    (mkdir_p s;
+     finally f s @@ fun () -> rm_rf s)
 
 type filter = (Re.t * filt_sort) list
 
@@ -270,9 +270,9 @@ type command =
         | `files of string (* file name *) ]
   | Pin_file_content of string
   | Opamfile of { files: string list;
-             filter: filter; }
+                  filter: filter; }
   | Json of { files: string list;
-             filter: filter; }
+              filter: filter; }
   | Cache of { kind: [`installed | `repo];
                switch: string;
                nvs: string list;
@@ -284,7 +284,9 @@ type command =
              output: string option;
              unordered: bool;
              sort: bool;}
+  | Set_os of string
   | Export of (string * [`eq | `pluseq | `eqplus] * string) list
+  | Unset of string list
   | Comment of string
 
 module Parse = struct
@@ -354,283 +356,336 @@ module Parse = struct
              with Not_found -> `opam)
         with Not_found ->
           File_contents (String.sub str 1 (String.length str - 2))
-      else if str.[0] = ':' || str.[0] = '#' then
-        Comment str
+    else if str.[0] = ':' || str.[0] = '#' then
+      Comment str
     else
       let varbinds, pos =
         let gr = exec (compile @@ rep re_varbind) str in
         List.map (fun gr ->
-          Group.get gr 1,
-          (match Group.get gr 2 with
-           | "=" -> `eq
-           | "+=" -> `pluseq
-           | "=+" -> `eqplus
-           | _ -> assert false),
-          get_str (Group.get gr 3))
-        (all (compile @@ re_varbind) (Group.get gr 0)),
-      Group.stop gr 0
-        in
-    let cmd, pos =
-      try
-        let gr = exec ~pos (compile re_str_atom) str in
-        Some (get_str (Group.get gr 0)),
+            Group.get gr 1,
+            (match Group.get gr 2 with
+             | "=" -> `eq
+             | "+=" -> `pluseq
+             | "=+" -> `eqplus
+             | _ -> assert false),
+            get_str (Group.get gr 3))
+          (all (compile @@ re_varbind) (Group.get gr 0)),
         Group.stop gr 0
-          with Not_found -> None, pos
-        in
-    let args =
-      let grs = all ~pos (compile re_str_atom) str in
-      List.map (fun gr -> Group.get gr 0) grs
       in
-    let get_str ?escape s =
-      str_replace_path ?escape OpamSystem.back_to_forward
-        (filters_of_var vars)
-        (get_str s)
-    in
-    let posix_re re =
-      try Posix.re (get_str ~escape:`Regexps re)
-      with Posix.Parse_error ->
-        failwith (Printf.sprintf "Bad POSIX regexp: %s" re)
-    in
-    let rec get_args_rewr acc = function
-      | [] -> List.rev acc, false, false, [], None
-      | ("|"|">$") :: _ as rewr ->
+      let cmd, pos =
+        try
+          let gr = exec ~pos (compile re_str_atom) str in
+          Some (get_str (Group.get gr 0)),
+          Group.stop gr 0
+        with Not_found -> None, pos
+      in
+      let args =
+        let grs = all ~pos (compile re_str_atom) str in
+        List.map (fun gr -> Group.get gr 0) grs
+      in
+      let get_str ?escape s =
+        str_replace_path ?escape OpamSystem.back_to_forward
+          (filters_of_var vars)
+          (get_str s)
+      in
+      let posix_re re =
+        try Posix.re (get_str ~escape:`Regexps re)
+        with Posix.Parse_error ->
+          failwith (Printf.sprintf "Bad POSIX regexp: %s" re)
+      in
+      let rec get_args_rewr acc = function
+        | [] -> List.rev acc, false, false, [], None
+        | ("|"|">$") :: _ as rewr ->
           let rec get_rewr (unordered, sort, acc) = function
             | "|" :: re :: "->" :: str :: r ->
-                get_rewr (unordered, sort, (posix_re re, Sed (get_str str)) :: acc) r
+              get_rewr (unordered, sort, (posix_re re, Sed (get_str str)) :: acc) r
             | "|" :: "grep" :: "-v" :: re :: r ->
-                get_rewr (unordered, sort, (posix_re re, GrepV) :: acc) r
+              get_rewr (unordered, sort, (posix_re re, GrepV) :: acc) r
             | "|" :: "grep" :: re :: r ->
-                get_rewr (unordered, sort, (posix_re re, Grep) :: acc) r
+              get_rewr (unordered, sort, (posix_re re, Grep) :: acc) r
             | "|" :: "sort" :: r ->
-                if acc <> [] then
-                  Printf.printf "Warning: sort should appear _before_ any filters\n%!";
-            get_rewr (unordered, true, acc) r
+              if acc <> [] then
+                Printf.printf "Warning: sort should appear _before_ any filters\n%!";
+              get_rewr (unordered, true, acc) r
             | "|" :: "unordered" :: r ->
-                get_rewr (true, sort, acc) r
+              get_rewr (true, sort, acc) r
             | "|" :: "sed-cmd" :: cmd :: r ->
-                let sandbox cmd =
-                  (* Sandbox prefix
-                 >[...] /tmp/build_592d92_dune/opam-reftest-2b89f9/OPAM/opam-init/hooks/sandbox.sh "build" "cmd" <
-                 >[...] ${BASEDIR}/opam-init/hooks/sandbox.sh "build" "cmd" <
-                 -->
+              let sandbox cmd =
+                (* Sandbox prefix
+                   >[...] /tmp/build_592d92_dune/opam-reftest-2b89f9/OPAM/opam-init/hooks/sandbox.sh "build" "cmd" <
+                   >[...] ${BASEDIR}/opam-init/hooks/sandbox.sh "build" "cmd" <
+                   -->
                    >[...] cmd <
-              *)
-                  seq [
-                    alt [ char '/'; Re.str "${" ];
-                non_greedy @@ rep1 any; Re.str "sandbox.sh";
-                space;
-                char '"';
-                alt @@ List.map Re.str [ "build"; "install"; "remove" ];
-                char '"';
-                space;
-                char '"'; Re.str cmd; char '"';
-                space;
+                *)
+                seq [
+                  alt [ char '/'; Re.str "${" ];
+                  non_greedy @@ rep1 any; Re.str "sandbox.sh";
+                  space;
+                  char '"';
+                  alt @@ List.map Re.str [ "build"; "install"; "remove" ];
+                  char '"';
+                  space;
+                  char '"'; Re.str cmd; char '"';
                 ]
-    in
-            let with_quote_set s = set ("\"'"^s) in
-            let opt_quoted r = [
-              seq @@ [ char '"'] @  r @ [ char '"'; rep1 space ];
-              seq @@ r @ [ rep1 space ];
+              in
+              let with_quote_set s = set ("\"'"^s) in
+              let opt_quoted r = [
+                seq @@ [ char '"'] @ r @ [ char '"' ];
+                seq @@ r;
               ] in
-            let unix_prefix cmd =
-              (* Unix & Mac command prefix
-                 >[...] /usr/bin/cmd <
-                 >[...] /usr/bin/cmd <
-                 -->
-                   >[...] cmd <
-              *)
-              opt_quoted @@ [
-                rep1 @@ seq [ char '/'; rep1 @@ diff any (with_quote_set "/ ") ];
-                char '/';
-                Re.str cmd;
+              let unix_prefix cmd =
+                (* Unix & Mac command prefix
+                   >[...] /usr/bin/cmd <
+                   >[...] /opt/homebrew/bin/cmd <
+                   -->
+                     >[...] cmd <
+                *)
+                opt_quoted @@ [
+                  rep1 @@ seq [ char '/'; rep1 @@ diff any (with_quote_set "/ ") ];
+                  char '/';
+                  Re.str cmd;
                 ]
-            in
-            let win_prefix cmd =
-              (* Windows command prefix
-                 >[...] C:\Windows\system32\cmd.exe <
-                 >[...] C:\Windows\system32\cmd <
-                 >[...] C:\Windows\system 32\cmd <
-                 -->
-                   >[...] cmd <
-              *)
-              opt_quoted @@ [
-                alpha; char ':';
-                rep1 @@ seq [ char '\\'; opt @@ char '\\';
-                              rep1 @@ diff any (with_quote_set "\\") ];
-                char '\\'; opt @@ char '\\';
-                Re.str cmd;
-                opt @@ Re.str ".exe";
+              in
+              let win_prefix cmd =
+                (* Windows command prefix
+                   >[...] C:\Windows\system32\cmd.exe <
+                   >[...] C:\Windows\system32\cmd <
+                   >[...] C:\Windows\system 32\cmd <
+                   -->
+                     >[...] cmd <
+                *)
+                opt_quoted @@ [
+                  alpha; char ':';
+                  rep1 @@ seq [ char '\\'; opt @@ char '\\';
+                                rep1 @@ diff any (with_quote_set "\\") ];
+                  char '\\'; opt @@ char '\\';
+                  Re.str cmd;
+                  opt @@ Re.str ".exe";
                 ] in
-            let re cmd = alt @@ sandbox cmd :: unix_prefix cmd @ win_prefix cmd in
-            let rec aux cmd r acc =
-              let str = Printf.sprintf "%s " cmd in
-              let acc = (re cmd, Sed str) :: acc in
-              match r with
-              | "|" :: _ | [] -> acc, r
-              | cmd :: r -> aux cmd r acc
-            in
-            let acc, r = aux cmd r acc in
-            get_rewr (unordered, sort, acc) r
+              let all_commands cmd = alt @@ sandbox cmd :: unix_prefix cmd @ win_prefix cmd in
+              let rec aux cmd r acc =
+                (* Middle of line but with space *)
+                let str = Printf.sprintf "%s " cmd in
+                let re cmd = seq [ all_commands cmd; space; ] in
+                let acc = (re cmd, Sed str) :: acc in
+                (* beginning of line, no space, but with verbose opam logs *)
+                let str = Printf.sprintf "+ %s" cmd in
+                let re cmd = seq [ bos; Re.str "+ "; all_commands cmd; ] in
+                let acc = (re cmd, Sed str) :: acc in
+                match r with
+                | "|" :: _ | [] -> acc, r
+                | cmd :: r -> aux cmd r acc
+              in
+              let acc, r = aux cmd r acc in
+              get_rewr (unordered, sort, acc) r
+            | "|" :: "sed-hash" :: hash :: r ->
+              let length = String.length hash in
+              if hash.[0] <> '$'
+              && length <> 32
+              && length <> 64
+              && length <> 128
+              then
+                (Printf.printf
+                   "Bad 'sed-hash' argument (%s), expecting a environment \
+                    variable beginning with '$' or a hash of 32, 64, \
+                    or 128 characters" hash;
+                 unordered, sort, List.rev acc, None)
+              else
+                let name, r =
+                  match r with
+                  | "|" :: _ | [] -> "hash", r
+                  | name :: r -> name, r
+                in
+                let name = "+"^name^"+" in
+                let re_hash = posix_re hash in
+                let sep = alt [ char '/' ; seq [ char '\\'; opt @@ char '\\'] ] in
+                let pre_t =
+                  seq [
+                    sep;
+                    repn xdigit 2 (Some 2);
+                  ] in
+                let pre_hash =
+                  seq [
+                    pre_t;
+                    sep;
+                    re_hash;
+                  ] in
+                let pre = seq [ pre_t; eos ] in
+                (* The order is important *)
+                let acc = (pre_hash, Sed ("/pre/"^name))::acc in
+                let acc = (re_hash, Sed name)::acc in
+                let acc = (pre, Sed "/pre")::acc in
+                get_rewr (unordered, sort, acc) r
             | ">$" :: output :: [] ->
-                unordered, sort, List.rev acc, Some (get_str output)
+              unordered, sort, List.rev acc, Some (get_str output)
             | [] ->
-                unordered, sort, List.rev acc, None
+              unordered, sort, List.rev acc, None
             | r ->
-                Printf.printf
-              "Bad rewrite %S, expecting '| RE -> STR' or '>$ VAR'\n%!"
-              (String.concat " " r);
-            unordered, sort, List.rev acc, None
-            in
-        let unordered, sort, rewr, out = get_rewr (false, false, []) rewr in
-        List.rev acc, unordered, sort, rewr, out
-            | arg :: r -> get_args_rewr (arg :: acc) r
-        in
-    let args, unordered, sort, rewr, output = get_args_rewr [] args in
-    match cmd with
-    | Some "opam-cat" ->
-        Opamfile { files = args; filter = rewr; }
-    | Some "json-cat" ->
-        Json { files = args; filter = rewr; }
-    | Some "opam-cache" ->
-      let kind, switch, nvs =
-        match args with
-        | "installed"::switch::nvs ->
-          `installed, switch, nvs
-        | "repo"::nvs ->
-          `repo, "", nvs
-        | _ ->
-          failwith
-            (Printf.sprintf
-               "Bad usage of opam-cache %s.\n\
-                expecting 'opam-cache <installed|repo> <switch?> [nvs]"
-             (String.concat " " args))
+              Printf.printf
+                "Bad rewrite %S, expecting '| RE -> STR' or '>$ VAR'\n%!"
+                (String.concat " " r);
+              unordered, sort, List.rev acc, None
+          in
+          let unordered, sort, rewr, out = get_rewr (false, false, []) rewr in
+          List.rev acc, unordered, sort, rewr, out
+        | arg :: r -> get_args_rewr (arg :: acc) r
       in
-      Cache { kind; switch; nvs; filter = rewr; }
-    | Some cmd ->
+      let args, unordered, sort, rewr, output = get_args_rewr [] args in
+      match cmd with
+      | Some "opam-cat" ->
+        Opamfile { files = args; filter = rewr; }
+      | Some "json-cat" ->
+        Json { files = args; filter = rewr; }
+      | Some "unset" ->
+        Unset args
+      | Some "opam-set-os" ->
+        (match args with
+         | os :: [] -> Set_os os
+         | _ -> failwith
+                  (Printf.sprintf
+                     "Bad usage of opam-set-os %s.\n\
+                      expecting 'opam-set-os [depext-test-specification]"
+                     (String.concat " " args)));
+      | Some "opam-cache" ->
+        let kind, switch, nvs =
+          match args with
+          | "installed"::switch::nvs ->
+            `installed, switch, nvs
+          | "repo"::nvs ->
+            `repo, "", nvs
+          | _ ->
+            failwith
+              (Printf.sprintf
+                 "Bad usage of opam-cache %s.\n\
+                  expecting 'opam-cache <installed|repo> <switch?> [nvs]"
+                 (String.concat " " args))
+        in
+        Cache { kind; switch; nvs; filter = rewr; }
+      | Some cmd ->
         let env, plus =
           List.fold_left (fun (env,plus) (v,op,value) ->
-            match op with
-            | `eq -> (v,value)::env, plus
-            | `pluseq -> env, (v^"+="^value)::plus
-            | `eqplus -> env, (v^"=+"^value)::plus)
-          ([],[]) varbinds
-    in
-      (match plus with
-       | [] -> ()
-       | _ ->
+              match op with
+              | `eq -> (v,value)::env, plus
+              | `pluseq -> env, (v^"+="^value)::plus
+              | `eqplus -> env, (v^"=+"^value)::plus)
+            ([],[]) varbinds
+        in
+        (match plus with
+         | [] -> ()
+         | _ ->
            OpamConsole.error
-           "variable bindings at the beginning of a command does not \
-            support '+=' or '=+' operators: %s"
-           (OpamStd.Format.pretty_list plus));
-      Run {
-        env;
-        cmd;
-        args;
-        filter = rewr;
-        output;
-        unordered;
-        sort;
+             "variable bindings at the beginning of a command does not \
+              support '+=' or '=+' operators: %s"
+             (OpamStd.Format.pretty_list plus));
+        Run {
+          env;
+          cmd;
+          args;
+          filter = rewr;
+          output;
+          unordered;
+          sort;
         }
-       | None ->
-           Export varbinds
-    end
+      | None ->
+        Export varbinds
+end
 
 let parse_command = Parse.command
 
 let common_filters ?opam dir =
-   let tmpdir = OpamSystem.real_path (Filename.get_temp_dir_name ()) in
-   let open Re in
-   let dir_to_regex dir =
-     if Sys.win32 then
-       [str dir; str (OpamSystem.back_to_forward dir); str (OpamSystem.apply_cygpath dir)]
-     else
-       [str dir] in
-   let with_hexa_twice prefix =
-     seq [
-       str prefix;
-       char '-';
-       repn xdigit 3 (Some 9);
-       char '-';
-       repn xdigit 3 (Some 9);
-     ]
-   in
-   [
-     seq [ bol;
-           alt [ str "#=== ERROR";
-                 seq [ str "# "; alt @@ List.map str
-                         [ "context";
-                           "path";
-                           "command";
-                           "exit-code";
-                           "env-file";
-                           "output-file"]]]],
-     GrepV;
-     seq [bol; str cmd_prompt],
-     Sed "##% ";
-     alt (dir_to_regex dir),
-     Sed "${BASEDIR}";
-     seq [
-          alt (dir_to_regex tmpdir);
-          rep (set "/\\");
-          str "opam-";
-          rep1 (alt [xdigit; char '-'])],
-     Sed "${OPAMTMP}";
-     seq [
-       str "state-";
-       repn digit 14 (Some 14);
-       str ".export";
-     ],
-     Sed "state-today.export";
-     seq [
-       str "state-";
-       repn xdigit 8 (Some 8);
-       str ".cache";
-     ],
-     Sed "state-magicv.cache";
-     with_hexa_twice "log",
-     Sed "log-xxx";
-     with_hexa_twice "patch",
-     Sed "patch-xxx";
-     (* rsync output
-        Linux
-        >sending incremental file list
-        MacOS
-        >building file list ... done
-     *)
-     alt [
-       seq [
-         rep any;
-         str "sending incremental file list";
-         rep any;
-       ];
-       seq [
-         rep any;
-         str "building file list"; rep any; str "done";
-         rep any;];
-     ],
-     GrepV;
-     (* rsync output
-        >sent 133 bytes  received 12 bytes  290.00 bytes/sec
-     *)
-     seq [
-       str "sent" ; rep1 space; rep1 digit; rep1 space; str "bytes"; rep1 space;
-       str "received"; rep1 space; rep1 digit; rep1 space; str "bytes";
-       rep1 any; str "bytes/sec"
-     ],
-     GrepV;
-     (* rsync output
-        >total size is 383  speedup is 0.58
-     *)
-     seq [
-       str "total"; rep1 space; str "size"; rep1 space; str "is"; rep1 space;
-       rep1 digit; rep1 space;
-       str "speedup"; rep1 space; str "is";
-     ],
-     GrepV
-   ] @
-   (match opam with
-    | None -> []
-    | Some opam -> [ str opam.as_seen_in_opam, Sed "${OPAM}" ])
+  let tmpdir = OpamSystem.real_path (Filename.get_temp_dir_name ()) in
+  let open Re in
+  let dir_to_regex dir =
+    if Sys.win32 then
+      [str dir; str (OpamSystem.back_to_forward dir); str (OpamSystem.apply_cygpath dir)]
+    else
+      [str dir] in
+  let with_hexa_twice prefix =
+    seq [
+      str prefix;
+      char '-';
+      repn xdigit 3 (Some 9);
+      char '-';
+      repn xdigit 3 (Some 9);
+    ]
+  in
+  [
+    seq [ bol;
+          alt [ str "#=== ERROR";
+                seq [ str "# "; alt @@ List.map str
+                        [ "context";
+                          "path";
+                          "command";
+                          "exit-code";
+                          "env-file";
+                          "output-file"]]]],
+    GrepV;
+    seq [bol; str cmd_prompt],
+    Sed "##% ";
+    alt (dir_to_regex dir),
+    Sed "${BASEDIR}";
+    seq [
+      alt (dir_to_regex tmpdir);
+      rep (set "/\\");
+      str "opam-";
+      rep1 (alt [xdigit; char '-'])],
+    Sed "${OPAMTMP}";
+    seq [
+      str "state-";
+      repn digit 14 (Some 14);
+      str ".export";
+    ],
+    Sed "state-today.export";
+    seq [
+      str "state-";
+      repn xdigit 8 (Some 8);
+      str ".cache";
+    ],
+    Sed "state-magicv.cache";
+    with_hexa_twice "log",
+    Sed "log-xxx";
+    with_hexa_twice "patch",
+    Sed "patch-xxx";
+    (* rsync output
+       Linux
+       >sending incremental file list
+       MacOS
+       >building file list ... done
+    *)
+    alt [
+      seq [
+        rep any;
+        str "sending incremental file list";
+        rep any;
+      ];
+      seq [
+        rep any;
+        str "building file list"; rep any; str "done";
+        rep any;];
+    ],
+    GrepV;
+    (* rsync output
+       >sent 133 bytes  received 12 bytes  290.00 bytes/sec
+    *)
+    seq [
+      str "sent" ; rep1 space; rep1 digit; rep1 space; str "bytes"; rep1 space;
+      str "received"; rep1 space; rep1 digit; rep1 space; str "bytes";
+      rep1 any; str "bytes/sec"
+    ],
+    GrepV;
+    (* rsync output
+       >total size is 383  speedup is 0.58
+    *)
+    seq [
+      str "total"; rep1 space; str "size"; rep1 space; str "is"; rep1 space;
+      rep1 digit; rep1 space;
+      str "speedup"; rep1 space; str "is";
+    ],
+    GrepV
+  ] @
+  (match opam with
+   | None -> []
+   | Some opam -> [ str opam.as_seen_in_opam, Sed "${OPAM}" ])
 
 let run_cmd ~opam ~dir ?(vars=[]) ?(filter=[]) ?(silent=false) ?(sort=false) cmd args =
   let filter = filter @ common_filters ~opam dir in
@@ -672,7 +727,7 @@ let print_opamfile file =
          pelem =
            Section {s with
                     section_name =
-                      OpamStd.Option.map (fun v ->
+                      Option.map (fun v ->
                           {v with pelem = mangle_string v.pelem})
                         s.section_name;
                     section_items =
@@ -979,6 +1034,8 @@ let run_test ?(vars=[]) ~opam t =
                in
                (v, value) :: List.filter (fun (w, _) -> not (String.equal v w)) vars)
             vars bindings
+        | Unset l ->
+          List.filter (fun (w, _) -> not (List.exists (fun v -> String.equal v w) l)) vars
         | Opamfile { files; filter } ->
           let files =
             List.map (fun s ->
@@ -1148,7 +1205,7 @@ let run_test ?(vars=[]) ~opam t =
                  List.length (matching e) > List.length (matching acc)
                in
                match r, e with
-               | r, el::e when List.mem el acc ->
+               | r, el::e when OpamStd.List.mem String.equal el acc ->
                  print_endline el; diffl (list_remove el acc) r e
                | rl::r, el::e ->
                  if rl = el then (print_endline el; diffl acc r e)
@@ -1160,10 +1217,14 @@ let run_test ?(vars=[]) ~opam t =
                  assert (acc = []); List.iter print_endline r
              in
              diffl [] (String.split_on_char '\n' r) out);
-          OpamStd.Option.iter (Printf.printf "# Return code %d #\n") errcode;
-          match output with
-          | None -> vars
-          | Some v -> (v, r) :: List.filter (fun (w,_) -> v <> w) vars)
+          Option.iter (Printf.printf "# Return code %d #\n") errcode;
+          (match output with
+           | None -> vars
+           | Some v -> (v, r) :: List.filter (fun (w,_) -> v <> w) vars)
+        | Set_os os ->
+          ignore @@ run_cmd ~opam ~dir ~vars
+            "opam" ["var"; "--global"; Printf.sprintf "os-family=%s" os];
+          vars)
       vars
       t.commands
   in
